<?php

###############################################################################
# polish.php
# This is the Polish language file for Geeklog!
# Special thanks to Robert Stadnik geeklog@geeklog.now.pl for his work on this project
#
# Copyright (C) 2000 Jason Whittenburg
# jwhitten@securitygeeks.com
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
###############################################################################

$LANG_CHARSET = 'iso-8859-2';

###############################################################################
# Array Format:
# $LANGXX[YY]:  $LANG - variable name
#               XX    - file id number
#               YY    - phrase id number
###############################################################################

###############################################################################
# USER PHRASES - These are file phrases used in end user scripts
###############################################################################

###############################################################################
# lib-common.php

$LANG01 = array(
    1 => 'Autor:',
    2 => 'czytaj dalej',
    3 => 'komentarzy',
    4 => 'Edycja',
    5 => '',
    6 => '',
    7 => '',
    8 => '',
    9 => 'Menu Admina:',
    10 => 'Panel Sterowania',
    11 => 'Artykuy',
    12 => 'Bloki',
    13 => 'Sekcje',
    14 => '',
    15 => '',
    16 => '',
    17 => 'Uytkownicy',
    18 => 'Zapytanie SQL',
    19 => 'Wyloguj',
    20 => 'Informacje Uytkownika:',
    21 => 'Login',
    22 => 'ID Uytkownika',
    23 => 'Poziom Zabezpiecze',
    24 => 'Gall Anonim',
    25 => 'Komentuj',
    26 => 'Komentarze nale do osb, ktre je zamieciy. Nie bierzemy odpowiedzialnoci za ich tre.',
    27 => 'Najnowsze Komentarze',
    28 => 'Kasuj',
    29 => 'Komentarzy Brak.',
    30 => 'Starsze Artykuy',
    31 => 'Dozwolone Znaczniki HTML:',
    32 => 'Bd, niewaciwy login',
    33 => 'Bd, nie mona zapisa w logu',
    34 => 'Bd',
    35 => 'Wyloguj',
    36 => 'dnia',
    37 => 'Brak artykuw uytkownika',
    38 => 'Syndykacja Treci',
    39 => 'Odwie',
    40 => '',
    41 => 'Go',
    42 => 'Autor:',
    43 => 'Odpowiedz',
    44 => 'Gwny',
    45 => 'Numer Bdu MySQL',
    46 => 'Numer Komunikatu Bdu MySQL',
    47 => 'Menu Uytkownika',
    48 => 'Konto - Info',
    49 => 'Osobiste',
    50 => 'Bdna skadnia SQL',
    51 => 'pomoc',
    52 => 'Nowy',
    53 => 'Panel Sterowania',
    54 => 'Nie mona otworzy pliku.',
    55 => 'Bd przy',
    56 => 'Gosuj',
    57 => 'Haso',
    58 => 'Login',
    59 => "Nie masz jeszcze konta? Za sobie <a href=\"{$_CONF['site_url']}/users.php?mode=new\" rel=\"nofollow\">Nowy Uytkownik</a>",
    60 => 'Komentarze',
    61 => 'Za Konto',
    62 => 'sw',
    63 => 'Komentarze - Preferencje',
    64 => 'Wylij Znajomemu',
    65 => 'Wersja do Wydruku',
    66 => '',
    67 => 'Witaj w Serwisie ',
    68 => 'strona gwna',
    69 => 'kontakt',
    70 => 'szukaj',
    71 => 'napisz',
    72 => 'linki',
    73 => '',
    74 => '',
    75 => 'zaawansowane szukanie',
    76 => 'statystyka',
    77 => 'Pluginy',
    78 => '',
    79 => 'Co Nowego',
    80 => 'artykuw w ost.',
    81 => 'artyku w ost.',
    82 => 'godz',
    83 => 'KOMENTARZE',
    84 => '',
    85 => 'wygasaj po 48 h',
    86 => 'Brak nowych komentarzy',
    87 => 'wygasaj po 2 tyg',
    88 => '',
    89 => '',
    90 => 'Strona Gwna',
    91 => 'Strona wygenerowana w ',
    92 => 'sekund',
    93 => 'Prawa Autorskie',
    94 => 'Wszelkie znaki handlowe i prawa autorskie nale do ich wacicieli.',
    95 => 'Wersja',
    96 => 'Grupy',
    97 => 'Lista Sw',
    98 => 'Pluginy',
    99 => 'ARTYKUY',
    100 => 'Brak nowych artykuw',
    101 => '',
    102 => '',
    103 => 'Kopie zapasowe bazy',
    104 => 'przez',
    105 => 'Wylij Maila',
    106 => 'Odson',
    107 => 'Wersja GL - Test',
    108 => 'Oprnij Cache',
    109 => 'Zgo naduycie',
    110 => 'Powiadom administratora o tym wpisie',
    111 => '',
    112 => 'Zarejestrowani Uytkownicy',
    113 => 'Dokumentacja',
    114 => 'POWIADOMIENIA ZWROTNE',
    115 => 'Brak nowych powiadomie zwrotnych dla komentarzy',
    116 => 'Powiadomienia zwrotne',
    117 => 'Katalog',
    118 => 'Dalszy cig na kolejnej stronie:',
    119 => "Nie pamitasz <a href=\"{$_CONF['site_url']}/users.php?mode=getpassword\" rel=\"nofollow\">hasa</a>?",
    120 => 'Stay odnonik do tego komentarza',
    121 => 'Komentarze (%d)',
    122 => 'Powiadomienia zwrotne (%d)',
    123 => 'Wszystkie znaczniki HTML s dozwolone',
    124 => 'Kliknij aby usun wszystkie zaznaczone pozycje',
    125 => 'Czy aby na pewno chcesz Usun wszystkie zaznaczone pozycje?',
    126 => 'Zaznacz lub odznacz wszystkie pozycje',
    127 => 'Stay odnonik',
    128 => 'Zaloguj z OpenID:',
    129 => 'Konfiguracja',
    130 => 'Usugi Web-owe'
);

###############################################################################
# comment.php

$LANG03 = array(
    1 => 'Napisz Komentarz',
    2 => 'Format',
    3 => 'Wyloguj',
    4 => 'Za Konto',
    5 => 'Login',
    6 => 'Aby zamieci komentarz naley si zalogowa.  Jeli nie masz jeszcze konta, za sobie uywajc poniszego formularza.',
    7 => 'Ostatni komentarz zamiecie ',
    8 => " sekund temu.  Wymagana jest przerwa rwna {$_CONF['commentspeedlimit']} sekund pomidzy komentarzami",
    9 => 'Komentarz',
    10 => 'Wylij Raport',
    11 => 'Wylij Komentarz',
    12 => 'Prosz uzupeni pola Tytu i Komentarz. Pola te s wymagane do zamieszczenia komentarza.',
    13 => 'Twoje Informacje',
    14 => 'Podgld',
    15 => 'Zgo t wiadomo',
    16 => 'Tytu',
    17 => 'Bd',
    18 => 'Wane Informacje',
    19 => 'Prosz stara si nie odbiega od tematu.',
    20 => 'Prosz raczej odpowiada na zamieszczane komentarze innych uytkownikw zamiast rozpoczynania nowych wtkw.',
    21 => 'Aby unikn powtarzania, zanim zamiecisz swj komentarz przeczytaj co napisali inni.',
    22 => 'Wpisz temat adekwatny do treci wiadomoci.',
    23 => 'Twj adres email nie bdzie ujawniony.',
    24 => 'Gall Anonim',
    25 => 'Czy chcesz zgosi administratorowi ten komentarz?',
    26 => '%s zgosi nastpujcy komentarz:',
    27 => 'Raport naduy',
    28 => 'Preview Changes',
    29 => 'Submit Changes',
    30 => 'Edited on',
    31 => 'by',
    32 => 'Editing a Comment',
    33 => 'Editing a Comment Submission',
    34 => 'Preview Submission Changes',
    35 => 'Save Changes to Queue',
    36 => 'Notify me of new replies',
    37 => 'New Comment Reply',
    38 => 'A reply has been made to your comment \'%s\'.',
    39 => 'You may view the comment thread at the following address:',
    40 => 'If you wish to receive no further notifications of replies, visit the following link:',
    41 => 'Hello %s,',
    42 => 'Unsubscribe',
    43 => 'Unsubscribe from reply notifications',
    44 => 'Your Name'
);

###############################################################################
# users.php

$LANG04 = array(
    1 => 'Profil Uytkownika',
    2 => 'Login',
    3 => 'Nazwa',
    4 => 'Haso',
    5 => 'Email',
    6 => 'Strona Domowa',
    7 => 'O Sobie',
    8 => 'Klucz PGP',
    9 => 'Zapisz Informacje',
    10 => 'Ostatnie 10 komentarzy uytkownika',
    11 => 'Brak Komentarzy Uytkownika',
    12 => 'Preferencje Uytkownika',
    13 => 'Dzienne Zestawienie Artykuw',
    14 => 'Haso jest generowane automatycznie. Zalecana jest szybka zmiana hasa. Aby zmieni haso, naley si zalogowa a nastpnie klikn na Konto Info w Menu Uytkownika.',
    15 => "Twoje {$_CONF['site_name']} konto zostao zaoone. Zaloguj si wykorzystujc informacje poniej. Prosz zachowa tego maila w bezpiecznym miejscu.",
    16 => 'Informacje Dotyczce Twojego Konta',
    17 => 'Konto nie istnieje',
    18 => 'Podany adres email nie jest prawidowy',
    19 => 'Podany login lub adres email ju istnieje',
    20 => 'Podany adres email nie jest prawidowy',
    21 => 'Bd',
    22 => "Zarejestruj si w serwisie {$_CONF['site_name']}!",
    23 => "Konto w serwisie {$_CONF['site_name']} pozwoli ci zamieszcza komentarze i inne pozycje w twoim imieniu. Brak konta umoliwia tylko zamieszczanie jako anonim. Twj adres email <b><i>nigdy</i></b> nie bdzie widoczny publicznie.",
    24 => 'Twoje haso zostanie wysane pod podany adres email.',
    25 => 'Nie pamitasz hasa?',
    26 => 'Wpisz <em>albo</em> swj login <em>albo</em> adres email podany podczas rejestracji i kliknij Przelij Haso. Instrukcje jak ustawi nowe haso zostan wysane do Ciebie mailem.',
    27 => 'Zarejestruj Si!',
    28 => 'Przelij Haso',
    29 => 'wylogowany z adresu',
    30 => 'zalogowany z adresu',
    31 => 'Wybrana funkcja wymaga wczeniejszego zalogowania',
    32 => 'Podpis',
    33 => 'Niewidoczne dla publiki',
    34 => 'Twoje prawdziwe imi',
    35 => 'Wpisz nowe haso',
    36 => 'Pocztek od http://',
    37 => 'Zastosowane do twoich komentarzy',
    38 => 'Wszystko o tobie! Kady moe to przeczyta',
    39 => 'Twj publiczny klucz PGP dla wszystkich',
    40 => 'Bez Ikon Sekcji',
    41 => 'Chtny/a do Zatwierdzania Materiaw',
    42 => 'Format Daty',
    43 => 'Artykuy Max Ilo',
    44 => 'Bez blokw',
    45 => 'Wygld - Ustawienia Uytkownika',
    46 => 'Wyczone Pozycje Uytkownika',
    47 => 'Konfiguracja Blokw z Nowociami Uytkownika',
    48 => 'Sekcje',
    49 => 'Bez ikon w artykuach',
    50 => 'Odznacz jeli nie jeste zainteresowany',
    51 => 'Tylko nowe artykuy',
    52 => 'Domylnie jest',
    53 => 'Otrzymujesz nowe artykuy co wieczr',
    54 => 'Zaznacz sekcje i autorw, ktrych nie chcesz oglda.',
    55 => 'Jeli nic nie zaznaczysz oznacza to, e akceptujesz domyln konfiguracj. Przy zaznaczaniu wybranych blokw domylne ustawienie jest anulowane. Nazwy blokw objtych domylnym ustawieniem s pogrubione.',
    56 => 'Autorzy',
    57 => 'Wywietlanie',
    58 => 'Sortowanie wg',
    59 => 'Limit Komentarzy',
    60 => 'Jak chcesz wywietla swoje komentarze?',
    61 => 'Od najnowszych czy od najstarszych?',
    62 => 'Domylnie jest 100',
    63 => "Haso zostao wysane i powinno wkrtce do ciebie dotrze. Postpuj zgodnie ze wskazwkami w wiadomoci. Dzikujemy za korzystanie z serwisu {$_CONF['site_name']}",
    64 => 'Komentarze - Ustawienia Uytkownika',
    65 => 'Sprbuj Zalogowa si Ponownie',
    66 => "By moe login zosta bdnie wpisany.  Sprbuj zalogowa si ponownie. Czy jeste <a href=\"{$_CONF['site_url']}/users.php?mode=new\" rel=\"nofollow\">nowym uytkownikiem</a>?",
    67 => 'Czonkowstwo Od',
    68 => 'Pamitaj Mnie Przez',
    69 => 'Jak dugo pamita ci po zalogowaniu?',
    70 => "Dostosuj wygld i zawarto serwisu {$_CONF['site_name']}",
    71 => "Jedn z extra moliwoci serwisu {$_CONF['site_name']} jest moliwo dopasowania zawartoci i wygldu strony.  Aby skorzysta z tych udogodnie naley si najpierw <a href=\"{$_CONF['site_url']}/users.php?mode=new\" rel=\"nofollow\">zarejestrowa</a> w serwisie {$_CONF['site_name']}.  Jeste ju czonkiem?  Zaloguj si!",
    72 => 'Pulpit',
    73 => 'Jzyk',
    74 => 'Zmie wygld strony!',
    75 => 'Artykuy Wysyane Mailem do',
    76 => 'Jeeli zaznaczysz jak sekcj z poniszej listy bdziesz, pod koniec kadego dnia, otrzymywa nowe artykuy zamieszczone w tej sekcji. Zaznacz sekcje, ktre ci interesuj!',
    77 => 'Zdjcie',
    78 => 'Dodaj swoje zdjcie!',
    79 => 'Zaznacz tutaj aby wykasowa to zdjcie',
    80 => 'Logowanie',
    81 => 'Wylij Maila',
    82 => '10 najnowszych artykuw uytkownika',
    83 => 'Materiay zamieszczone przez uytkownika',
    84 => 'Wszystkich artykuw:',
    85 => 'Wszystkich komentarzy:',
    86 => 'Znajd wszystkie materiay zamieszczone przez',
    87 => 'Twj login',
    88 => "Kto (prawdopodobnie Ty) chce uzyska nowe haso do tego konta \"%s\" w {$_CONF['site_name']}, <{$_CONF['site_url']}>.\n\nJeli chcesz kontynuowa prosz kliknij ten link:\n\n",
    89 => "Jeli nie chcesz kontynuowa, zignoruj t wiadomo (Twoje haso pozostanie niezmienione).\n\n",
    90 => 'Poniej moesz wprowadzi nowe haso. Pamitaj, e stare haso jest aktywne do czasu przesania tego zgoszenia.',
    91 => 'Ustaw Nowe Haso',
    92 => 'Wpisz Nowe Haso',
    93 => 'Twoja ostatnia proba o zmian hasa bya wysana %d sekund temu. Wymagana jest przerwa co najmniej %d sekundowa pomidzy takimi zgoszeniami.',
    94 => 'Kasuj Konto "%s"',
    95 => 'Kliknij poniszy przycisk "kasuj konto" aby usun swoje konto z bazy danych. Prosz mie na uwadze, e wszelkie artykuy i komentarze, zamieszczone przez Ciebie <strong>nie</strong> zostan usunite ale autor zmieni si na "Gall Anonim".',
    96 => 'kasuj konto',
    97 => 'Potwierd Usunicie Konta',
    98 => 'Czy aby napewno chcesz usun swoje konto? Po skasowaniu konta nie bdzie mona si ponownie zalogowa na tej stronie (chyba, e zaoysz nowe konto). Jeli tego chcesz kliknij ponownie "kasuj konto" w poniszym formularzu.',
    99 => 'Ochrona Prywatnoci dla',
    100 => 'Email od Admina',
    101 => 'TAK na emaile od Admina',
    102 => 'Email od Uytkownikw',
    103 => 'TAK na emaile od innych uytkownikw',
    104 => 'Poka Status Online',
    105 => 'Poka w bloku Who\'s Online',
    106 => 'Lokalizacja',
    107 => 'Poka w swoim publicznym profilu',
    108 => 'Potwierd nowe haso',
    109 => 'Wpisz tutaj ponownie Nowe haso',
    110 => 'Obecne Haso',
    111 => 'Prosz wpisa swoje Obecne haso',
    112 => 'You have exceeded the number of allowed login attempts.  Please try again later.',
    113 => 'Nieudana Prba Zalogowania',
    114 => 'Konto WYczone',
    115 => 'Twoje konto zostao wyczone, nie mona si zalogowa. Prosz skontaktowa si z Administratorem.',
    116 => 'Konto Czeka Na Aktywacj',
    117 => 'Twoje konto czeka obecnie na aktywacj przez administratora. You will not be able to login until your account has been approved.',
    118 => "Your {$_CONF['site_name']} account has now been activated by an administrator. You may now login to the site at the url below using your username (<username>) and password as previously emailed to you.",
    119 => 'Jeli nie pamitasz swojego hasa, kliknij na ten odnonik aby otrzyma nowe:',
    120 => 'Konto Zostao Aktywowane',
    121 => 'Service',
    122 => 'Przepraszamy, rejestracja nowych uytkownikw jest wyczona',
    123 => "Czy jeste <a href=\"{$_CONF['site_url']}/users.php?mode=new\" rel=\"nofollow\">nowym uytkownikiem</a>?",
    124 => 'Potwierdzenie Adresu Email',
    125 => 'W obu polach naley wpisa taki sam adres email!',
    126 => 'Please repeat for confirmation',
    127 => 'Aby zmieni ktrekolwiek z tych ustawie, musisz poda swoje biece haso.',
    128 => 'Twoje Imi',
    129 => 'Haso &amp; Email',
    130 => 'O Sobie',
    131 => 'Daily Digest Options',
    132 => 'Daily Digest Feature',
    133 => 'Wywietlanie Komentarzy',
    134 => 'Opcje Komentarzy',
    135 => '<li>Domylny tryb wywietlania komentarzy</li><li>Domylne sortowanie komentarzy</li><li>Liczba wywietlanych komentarzy - domylnie jest 100</li>',
    136 => 'Nie Pokazuj Tematw i Autorw',
    137 => 'Filtruj Zawarto Artykuw',
    138 => 'Ustawienia Rne',
    139 => 'Layout i Jzyk',
    140 => '<li>No Topic Icons if checked will not display the story topic icons</li><li>No boxes if checked will only show the Admin Menu, User Menu and Topics</li><li>Set the maximum number of stories to show per page</li><li>Set your theme, timezone and preferred date format</li>',
    141 => 'Ustawienia Prywatnoci',
    142 => 'The default setting is to allow users & admins to email fellow site members and show your status as online. Un-check these options to protect your privacy.',
    143 => 'Filtruj Zawarto Blokw',
    144 => 'Poka & ukryj pola',
    145 => 'Twj Profil Publiczny',
    146 => 'Haso i email',
    147 => 'Edit your account password, email and autologin feature. You will need to enter the same password or email address twice as a confirmation.',
    148 => 'Informacje o Uytkowniku',
    149 => 'Modify your user information that will be shown to other users.<li>The signature will be added to any comments or forum posts you made</li><li>The BIO is a brief summary of yourself to share</li><li>Share your PGP Key</li>',
    150 => 'Uwaga: Javascript jest rekomendowany aby korzysta z zaawansowanych funkcji',
    156 => 'Usu Konto',
    157 => 'Delete Option',
    158 => 'Strefa Czasowa',
    159 => 'Ta wiadomo zostaa wygenerowana automatycznie. Prosz nie odpowiada.',
    160 => '(max. %d x %d pixels, %d bytes; %s)',
    161 => 'will be scaled down',
    162 => 'will not be scaled',
    163 => 'Re-Authentication Failed',
    164 => 'You have exceeded the number of allowed attempts for re-authentication. The operation has been aborted and your recent changes were lost, sorry.',
    165 => 'Use Advanced Editor'
);

###############################################################################
# Customize if need to modify the Tabbed navbar MyAccount panels used.
# Array index key matches preference div id

$LANG_MYACCOUNT = array(
    'pe_preview' => 'Podgld',
    'pe_namepass' => 'Uytkownik &amp; Haso',
    'pe_userinfo' => 'O Sobie',
    'pe_layout' => 'Layout &amp; Jzyk',
    'pe_content' => 'Zawarto',
    'pe_privacy' => 'Prywtno'
);

###############################################################################
# index.php

$LANG05 = array(
    1 => 'Brak Nowoci',
    2 => 'Brak nowych artykuw.  By moe nie ma nowych artykuw w danej sekcji lub twoje ustawienia s zbyt limitujce.',
    3 => 'dla sekcji %s',
    4 => 'Dzisiejszy Artyku Dnia',
    5 => 'Nastpny',
    6 => 'Poprzedni',
    7 => 'Pierwszy',
    8 => 'Ostatni'
);

###############################################################################
# profiles.php

$LANG08 = array(
    1 => 'Wystpi bd podczas wysyania wiadomoci. Sprbuj ponownie.',
    2 => 'Wiadomo wysano.',
    3 => 'Prosz si upewni, e adres email wpisany w pole Odpowiedz Do jest prawidowy.',
    4 => 'Prosz si Przedstawi, wpisa Odpowiedz Do, Temat i Wiadomo',
    5 => 'Bd: Nie ma takiego uytkownika.',
    6 => 'Wystpi bd.',
    7 => 'Profil Uytkownika',
    8 => 'Uytkownik',
    9 => 'URL Uytkownika',
    10 => 'Wylij maila do',
    11 => 'Przedstaw Si:',
    12 => 'Twj email:',
    13 => 'Temat:',
    14 => 'Wiadomo:',
    15 => 'Bez znacznikw HTML.',
    16 => 'Wylij',
    17 => 'Wylij Znajomemu',
    18 => 'Do (twj znajomy)',
    19 => 'Jego/Jej Adres Email',
    20 => 'Od (Przedstaw si;-)',
    21 => 'Twj Adres Email',
    22 => 'Naley wypeni wszystkie pola',
    23 => "Tego maila wysa %s (%s) z myl, e moe ci zainteresowa poniszy artyku z serwisu {$_CONF['site_url']}.  To nie jest SPAM a uyte adresy email nie zostay nigdzie zapisane celem ich pniejszego wykorzystania.",
    24 => 'Skomentuj ten artyku tutaj',
    25 => 'Przed uyciem tej opcji musisz si zalogowa.  Pozwoli nam to zabezpieczy system przed niewaciwym wykorzystaniem',
    26 => 'Ten formularz umoliwia wysanie maila do wybranego uytkownika.  Wymagane jest wypenienie wszystkich pl.',
    27 => 'Krtka Wiadomo',
    28 => '%s napisa: ',
    29 => "Dzienne zestawienie artykuw w Serwisie {$_CONF['site_name']} z dnia ",
    30 => 'Newsletter z dnia ',
    31 => 'Tytu',
    32 => 'Data',
    33 => 'Cay artyku dostpny tutaj ',
    34 => 'Koniec Wiadomoci',
    35 => 'Sorry, ale ten uytkownik nie yczy sobie otrzymywania adnych emaili.',
    36 => 'Copy:',
    37 => 'Send me a copy of this email',
    38 => "This is a copy of the email that you sent to %s from <{$_CONF['site_url']}>:"
);

###############################################################################
# search.php

$LANG09 = array(
    1 => 'Wyszukiwanie Zaawansowane',
    2 => 'Sowa Kluczowe',
    3 => 'Sekcja',
    4 => 'Wszystko',
    5 => 'Gdzie',
    6 => 'Artykuy',
    7 => 'Komentarze',
    8 => 'Autorzy',
    9 => 'Wszystko',
    10 => 'Szukaj',
    11 => 'Wyniki',
    12 => 'trafienia',
    13 => 'Wyniki: Brak danych',
    14 => 'Nie znaleziono adnych danych speniajcych twoje kryteria',
    15 => 'Prosz sprbowa ponownie.',
    16 => 'Tytu',
    17 => 'Data',
    18 => 'Autor',
    19 => "Przeszukuje ca baz artykuw i komentarzy {$_CONF['site_name']} ",
    20 => 'Data',
    21 => 'do',
    22 => '(Format Daty RRRR-MM-DD)',
    23 => 'Odson',
    24 => 'Znaleziono %d pozycji',
    25 => 'Szukano',
    26 => 'pozycji ',
    27 => 'sekund',
    28 => 'Brak artykuw lub komentarzy ktrych szukasz',
    29 => 'Artykuy i Komentarze - Wyniki',
    30 => '',
    31 => 'Nie znaleziono adnych pluginw',
    32 => '',
    33 => 'URL',
    34 => 'Lokalizacja',
    35 => 'Cay Dzie',
    36 => '',
    37 => '',
    38 => '',
    39 => '',
    40 => '',
    41 => 'Twoje zapytanie powinno zawiera co najmniej 3 znaki.',
    42 => 'Prosz uywa nastpujcego formatu daty: RRRR-MM-DD (rok-miesic-dzie).',
    43 => 'z wyraeniem',
    44 => 'ze wszystkimi sowami',
    45 => 'z ktrymkolwiek ze sw',
    46 => 'Dalej',
    47 => 'Wstecz',
    48 => 'Autor',
    49 => 'Data',
    50 => 'Odson',
    51 => '',
    52 => 'Lokalizacja',
    53 => 'Artykuy - Wyniki',
    54 => 'Komentarze - Wyniki',
    55 => 'fraza',
    56 => 'AND',
    57 => 'OR',
    58 => 'WIcej wynikw &gt;&gt;',
    59 => 'Wyniki',
    60 => 'na stron',
    61 => 'Zmie zapytanie',
    62 => '#',
    63 => 'Description',
    64 => 'Showing %1$d - %2$d of %3$d results',
    65 => 'Story',
    66 => 'Comment',
    67 => 'Show %d Results',
    68 => 'Sort By',
    69 => 'Titles Only',
    70 => 'Not available ...',
    71 => 'asc',
    72 => 'desc'
);

###############################################################################
# stats.php

$LANG10 = array(
    1 => 'Statystyka Serwisu',
    2 => 'Wszystkich Wizyt w Serwisie',
    3 => 'Artykuw(Komentarzy) w Serwisie',
    4 => '',
    5 => '',
    6 => '',
    7 => '10 Najpopularniejszych Artykuw',
    8 => 'Tytu Artykuu',
    9 => 'Odson',
    10 => 'Wyglda na to, e w tym serwisie nie ma adnych artykuw albo nikt nigdy adnego nie przeczyta.',
    11 => '10 Najczciej Komentowanych Artykuw',
    12 => 'Komentarzy',
    13 => 'Wyglda na to, e w tym serwisie nie ma adnych artykuw albo nikt nigdy nie skomentowa adnego.',
    14 => '',
    15 => '',
    16 => '',
    17 => '',
    18 => '',
    19 => '',
    20 => '',
    21 => '',
    22 => '10 Najczciej Emaliowanych Artykuw',
    23 => 'Emaile',
    24 => 'Wyglda na to, e nikt nie przesa swoim znajomym adnego artykuu',
    25 => '10 Najczciej Komentowanych Zwrotnie Artykuw',
    26 => 'Brak komentarzy zwrotnych.',
    27 => 'Liczba aktywnych uytkownikw',
    28 => '',
    29 => '',
    30 => 'Odson',
    31 => ''
);

###############################################################################
# article.php

$LANG11 = array(
    1 => 'Odnoniki',
    2 => 'Wylij Znajomemu',
    3 => 'Wersja Do Wydruku',
    4 => 'Opcje Artykuu',
    5 => '',
    6 => 'Subscribe to \'%s\''
);

###############################################################################
# submit.php

$LANG12 = array(
    1 => 'Aby przesa %s musisz si wczeniej zalogowa.',
    2 => 'Login',
    3 => 'Nowy Uytkownik',
    4 => '',
    5 => '',
    6 => 'Przelij Artyku',
    7 => 'Wymagany jest Login',
    8 => 'Przelij',
    9 => 'Przy przesyaniu informacji do tego serwisu, prosimy postpowa wg poniszych wskazwek...<ul><li>Naley wypeni wszystkie pola<li>Zamieci pen i poprawn informacj<li>Sprawdzi dokadnie podawane adresy</ul>',
    10 => 'Tytu',
    11 => '',
    12 => 'Data Pocztkowa',
    13 => 'Data Kocowa',
    14 => 'Lokalizacja',
    15 => 'Opis',
    16 => '',
    17 => '',
    18 => '',
    19 => 'Przeczytaj Uwanie',
    20 => '',
    21 => '',
    22 => 'Bd: Puste Pola',
    23 => 'Wymagane jest wypenienie wszystkich pl formularza.',
    24 => 'Zapisano',
    25 => 'Twj materia %s zosta zapisany.',
    26 => 'Limit Czasowy',
    27 => 'Login',
    28 => 'Sekcja',
    29 => 'Artyku',
    30 => 'Ostatni raz przesyae ',
    31 => " sekund temu.  Wymagane jest co najmniej {$_CONF['speedlimit']} sekund przerwy pomidzy zamieszczeniami",
    32 => 'Podgld',
    33 => 'Podgld Artykuu',
    34 => 'Wyloguj',
    35 => 'Znaczniki HTML nie s dozwolone',
    36 => 'Format',
    37 => '',
    38 => '',
    39 => '',
    40 => '',
    41 => '',
    42 => '',
    43 => '',
    44 => 'Adres 1',
    45 => 'Adres 2',
    46 => 'Miasto/Miejscowo',
    47 => 'Wojewdztwo',
    48 => 'Kod Pocztowy',
    49 => '',
    50 => '',
    51 => 'Lokalizacja',
    52 => 'Kasuj',
    53 => 'Za Konto',
    54 => 'Artyku Wstp',
    55 => 'Artyku Cz Gwna'
);

###############################################################################
# ADMIN PHRASES - These are file phrases used in admin scripts
###############################################################################

###############################################################################
# admin/auth.inc.php

$LANG20 = array(
    1 => 'Wymagana jest Autoryzacja',
    2 => 'Odmowa! Niewaciwy Login',
    3 => 'Niewaciwe haso uytkownika',
    4 => 'Login:',
    5 => 'Haso:',
    6 => 'Wszelkie prby wejcia do segmentw administracyjnych s logowane i weryfikowane.<br' . XHTML . '>Dostp tylko dla osb upowanionych.',
    7 => 'login'
);

###############################################################################
# admin/block.php

$LANG21 = array(
    1 => 'Niewystarczajce Uprawnienia Administracyjne',
    2 => 'Nie masz wystarczajcych uprawnie do edycji tego bloku.',
    3 => 'Edytor Blokw',
    4 => 'Wystpi bd odczytu (szczegy w pliku error.log).',
    5 => '',
    6 => '',
    7 => 'Wszystkie',
    8 => 'Poziom Zabezpieczenia Bloku',
    9 => 'Numer Bloku',
    10 => '',
    11 => 'Blok Portalowy',
    12 => 'Blok Normalny',
    13 => 'Opcje Bloku Portalowego',
    14 => 'URL pliku RDF',
    15 => 'Ostatnie Uaktualnienie Pliku RDF',
    16 => 'Opcje Bloku Normalnego',
    17 => 'Zawarto Bloku',
    18 => 'Prosz wpisa Tytu Bloku, Poziom Zabezpieczenia i pola Zawartoci',
    19 => 'Menader Blokw',
    20 => '',
    21 => 'PozZab Bloku',
    22 => '',
    23 => 'Numer Bloku',
    24 => '',
    25 => 'Aby zmodyfikowa lub wykasowa blok kliknij na blok poniej.  Aby stworzy nowy blok kliknij Nowy Blok powyej.',
    26 => 'Blok Schematowy',
    27 => 'Blok PHP',
    28 => 'Opcje Bloku PHP',
    29 => 'Funkcje Bloku',
    30 => 'Jeli chcesz aby twj blok obsugiwa kod PHP, wpisz nazw funkcji powyej.  Nazwa funkcji musi rozpoczyna si prefiksem "phpblock_" (np. phpblock_getweather).  Jeeli nie bdzie prefiksu, twoja funkcja NIE zostanie wywoana.  Zwizane jest to z uniemoliwieniem \'wrzucania\' skryptw przez hakerw, ktre mog uszkodzi twj system.  Upewnij si, e nie ma pustych nawiasw "()" po nazwie funkcji.  Na koniec, zalecamy umieszczenie caego kodu PHP Block w /cieka/do/geeklog/system/lib-custom.php.  Pozwoli to na zachowanie wersji kodu bez zmian nawet przy aktualizacji Geekloga.',
    31 => 'Bd w Bloku PHP.  Funkcja, %s, nie istnieje.',
    32 => 'Bd. Puste pole(a)',
    33 => 'Musisz wpisa URL do pliku .rdf dla blokw portalowych',
    34 => 'Musisz wpisa tytu i funkcj blokw PHP',
    35 => 'Musisz wpisa tytu i zawarto dla blokw normalnych',
    36 => 'Musisz wpisa zawarto blokw schematowych',
    37 => 'Nieprawidowa nazwa funkcji bloku PHP',
    38 => 'Funkcje dla Blokw PHP musz mie prefiks \'phpblock_\' (np. phpblock_getweather).  Prefiks \'phpblock_\' ze wzgldw bezpieczestwa aby unikn wykonywanie kodu.',
    39 => 'Strona',
    40 => 'Lewa',
    41 => 'Prawa',
    42 => 'Musisz wpisa porzdek bloku i poziom zabezpiecze dla domylnych blokw Geekloga',
    43 => 'Tylko Strona Gwna',
    44 => '',
    45 => "Prbujesz wyedytowa blok, do ktrego nie masz uprawnie.  Ta prba zostaa zapisana w logu. Prosz <a href=\"{$_CONF['site_admin_url']}/block.php\">wrci do ekranu administrowania blokami</a>.",
    46 => 'Nowy Blok',
    47 => '',
    48 => 'Nazwa Bloku',
    49 => ' (nazwa unikalna i bez spacji)',
    50 => 'The Block Name can not be empty',
    51 => 'uwzgldnij http://',
    52 => 'Jeli zostawisz puste, ikona pomocy dla tego bloku si nie pojawi',
    53 => 'Aktywne',
    54 => 'zapisz',
    55 => 'anuluj',
    56 => 'kasuj',
    57 => 'Przesu Blok w D',
    58 => 'Przesu Blok w Gr',
    59 => 'Przesu blok na prawo',
    60 => 'Przesu blok w lewo',
    61 => 'Brak Tytuu',
    62 => 'Limit Artykuw',
    63 => 'Nieprawidwy Tytu Bloku',
    64 => 'Pole Tytu nie moe by puste i nie moe zawiera znacznikw HTML!',
    65 => 'Sorotwanie',
    66 => 'Autotagi',
    67 => 'Zaznacz aby wczy autotagi',
    68 => 'The feed for this portal block is too long to display. Please set a maximum number of articles to import for the block in the block setup screen, or a global maximum in Geeklog Configuration.'
);

###############################################################################
# admin/story.php

$LANG24 = array(
    1 => 'Poprzednie Artykuy',
    2 => 'Nastpne Artykuy',
    3 => 'Tryb',
    4 => 'Format',
    5 => 'Edytor Artykuw',
    6 => 'Brak artykuw w systemie',
    7 => 'Autor',
    8 => 'zapisz',
    9 => 'podgld',
    10 => 'anuluj',
    11 => 'kasuj',
    12 => 'ID',
    13 => '',
    14 => '',
    15 => 'Data',
    16 => 'Wstp',
    17 => 'Cz Gwna',
    18 => 'Wej',
    19 => 'Komentarze',
    20 => 'Ping',
    21 => 'Send Ping',
    22 => 'Lista Artykuw',
    23 => 'Aby zmodyfikowa lub wykasowa artyku, kliknij na numer danego artykuu poniej. Aby przegldn artyku kliknij na tytu danego artykuu. Aby wpisa nowy artyku kliknij na Nowy Artyku powyej.',
    24 => 'The ID you chose for this story is already in use. Please use another ID.',
    25 => 'Bd podczas zapisywania artykuu',
    26 => 'Podgld Artykuu',
    27 => 'Jeli uywasz [unscaledX] zamiast [imageX], zdjcie zostanie zamieszczone w oryginalnym rozmiarze.',
    28 => '<p><b>PODGLD</b>: Podgld artykuu z zaczonymi zdjciami dziaa najlepiej po uprzednim zapisaniu artykuu jako kopia robocza ZAMIAST klikaniu na przycisk podgldu.  Przycisk podgldu najlepiej uywa gdy nie zaczamy zdj.',
    29 => 'Trackbacks',
    30 => 'Bd Uploadu Pliku',
    31 => 'Prosz wpisa Tytu i Wstp',
    32 => 'Artyku Dnia',
    33 => 'Artyku Dnia moe by tylko jeden',
    34 => 'Wersja Robocza',
    35 => 'Tak',
    36 => 'Nie',
    37 => 'Wicej autorstwa',
    38 => 'Wicej z sekcji',
    39 => 'Emaile',
    40 => '',
    41 => "Prbujesz wyedytowa artyku do ktrego nie masz uprawnie.  Ta prba zostaa zapisana w logu.  Moesz podgldn artyku poniej. Prosz <a href=\"{$_CONF['site_admin_url']}/story.php\">wrci do strony administrujcej artykuami.",
    42 => "Prbujesz wyedytowa artyku do ktrego nie masz uprawnie.  Ta prba zostaa zapisana w logu.  Prosz <a href=\"{$_CONF['site_admin_url']}/story.php\">wrci do strony administrujcej artykuami</a>.",
    43 => '',
    44 => '',
    45 => '',
    46 => '<b>UWAGA:</b> jeli przesuniesz dat do przodu, artyku nie zostanie opublikowany wczeniej. Oznacza to rwnie, e artyku nie bdzie uwzgldniony w pliku RDF i zostanie pominity przy wyszukiwaniu.',
    47 => 'Zdjcia',
    48 => 'zdjcie',
    49 => 'prawo',
    50 => 'lewo',
    51 => 'Aby doda jedno ze zdj, ktre chcesz podpi do tego artykuu musisz wstawi specjalnie sformatowany tekst.  Tekst jest nastpujcy [imageX], [imageX_right] lub [imageX_left] gdzie X to numer obrazka, ktry zaczye.  UWAGA: Musisz uywa obrazkw, ktre zaczasz.  Inaczej nie bdziesz w stanie zapisa swojego artykuu.<BR><P><B>PODGLD</B>: Podgld artykuu z zaczonymi obrazkami dziaa najlepiej po uprzednim zapisaniu artykuu jako kopia ZAMIAST uycia bezporednio klawisza podgld.  Uywaj klawisza podgld tylko gdy nie podpinasz obrazkw.',
    52 => '',
    53 => 'nie zosta uyty.  Musisz umieci ten obrazek we wstpie lub w gwnej czci zanim zapiszsz zmiany',
    54 => 'Zaczonych Obrazw Nie Uyto',
    55 => 'Pojawiy si nastpujce bdy podczas prby zapisu tego artykuu.  Prosz je poprawi przed ponownym zapisem',
    56 => 'Poka Ikon Artykuu',
    57 => 'Poka nieskalowalne zdjcie',
    58 => 'Zarzdzanie Artykuami',
    59 => 'Opcja',
    60 => '',
    61 => 'Auto Archiwizacja',
    62 => 'Auto Kasacja',
    63 => 'Disable Comments',
    64 => '',
    65 => '',
    66 => '',
    67 => 'Powiksz Edytor',
    68 => 'Zmniejsz Edytor',
    69 => 'Data Publikacji Artykuu',
    70 => 'Wybr Paska Narzdzi',
    71 => 'Pasek Podstawowy',
    72 => 'Common Toolbar',
    73 => 'Pasek Zaawansowany',
    74 => 'Pasek Zaawansowany II',
    75 => 'Pena Opcja',
    76 => 'Opcje Publikowania',
    77 => 'Edytor Zaawansowany wymaga wczenia Javascript-u. Opcja moe zosta wyczona w gwnym pliku config.php',
    78 => 'Kliknij <a href="%s/story.php?mode=edit&amp;sid=%s&amp;editopt=default">tutaj</a> aby wczy edytor domylny',
    79 => 'Podgld',
    80 => 'Edytor',
    81 => 'Opcje Publikacji',
    82 => 'Zdjcia',
    83 => 'Opcje Archiwizacji',
    84 => 'Dostp',
    85 => 'Poka Wszystko',
    86 => 'Edytor Zaawansowany',
    87 => 'Artyku - Statystyki',
    88 => 'Format w stylu Wiki',
    89 => 'Meta Description',
    90 => 'Meta Keywords',
    91 => 'You can always hit "Preview" to extend the expiry time.'
);

###############################################################################
# admin/topic.php

$LANG27 = array(
    1 => 'Edytor Sekcji',
    2 => 'ID Sekcji',
    3 => 'Nazwa Sekcji',
    4 => 'Ikona Sekcji',
    5 => '(bez spacji)',
    6 => 'Wykasowanie sekcji wykasuje wszystkie artykuy i bloki z ni powizane',
    7 => 'Prosz wpisa ID Sekcji i Nazw Sekcji',
    8 => 'Menader Sekcji',
    9 => 'Aby zmodyfikowa lub wykasowa sekcj, kliknij na dan sekcj.  Aby stworzy now sekcj kliknij na Nowa Sekcja powyej. W nawiasie znajduje si twj poziom dostpu do kadej sekcji. Gwiazdka (*) oznacza domyln sekcj.',
    10 => 'Sortowanie',
    11 => 'Artykuw/Stron',
    12 => 'Odmowa Dostpu',
    13 => "Prbujesz wyedytowa sekcj do ktrej nie masz uprawnie.  Ta prba zostaa zapisana w logu. Prosz <a href=\"{$_CONF['site_admin_url']}/topic.php\">wrci do ekranu administrujcego sekcjami</a>.",
    14 => 'Sortuj Wg',
    15 => 'alfabetycznie',
    16 => 'domylnie jest',
    17 => 'Nowa Sekcja',
    18 => 'Panel Sterowania',
    19 => 'zapisz',
    20 => 'anuluj',
    21 => 'kasuj',
    22 => 'Domylnie',
    23 => 'zrb z tego domyln sekcj dla przesyanych artykuw',
    24 => '(*)',
    25 => 'Sekcja Archiwalna',
    26 => 'domylna sekcja dla archiwizowanych artykuw. Dozwolona jest tylko jedna sekcja.',
    27 => 'Lub Wgraj Ikon Sekcji',
    28 => 'Max',
    29 => 'Bd podczas przesyania pliku',
    30 => 'Stories in Topic'
);

###############################################################################
# admin/user.php

$LANG28 = array(
    1 => 'Edytor Uytkownikw',
    2 => 'ID Uytkownika',
    3 => 'Login',
    4 => 'Pena Nazwa',
    5 => 'Haso',
    6 => 'Poziom Zabezpieczenia',
    7 => 'Adres Email',
    8 => 'Strona Domowa',
    9 => '(bez spacji)',
    10 => 'Prosz wpisa Login i Adres Email',
    11 => 'Menader Uytkownikw',
    12 => 'Aby zmodyfikowa lub usun uytkownika, kliknij na odpowiedni login poniej.  Aby zaoy nowego uytkownika kliknij nowy uytkownik po lewej. Moesz przeszuka baz wpisujc cz loginu, adresu email lub penej nazwy (np. *son* lub *.edu) w poniszym formularzu.',
    13 => 'PozZab',
    14 => 'Data Rej.',
    15 => '',
    16 => '',
    17 => '',
    18 => '',
    19 => '',
    20 => 'zapisz',
    21 => 'Login ju istnieje.',
    22 => 'Bd',
    23 => 'Dodanie Grupowe',
    24 => 'Grupowy Import Uytkownikw',
    25 => 'Mona zaimportowa grupowo uytkownikw do Geekloga.  Plik tekstowy musi by rozdzielany znakami tabulacji oraz musi mie nastpujc struktur: imi i nazwisko, login, adres email.  Kady zaimportowany uytkownik dostanie mailem haso.  W jednej linii moe wystpowa tylko jeden uytkownik.  Nie zastosowanie do tych instrukcji spowoduje problemy, ktre mog wymaga rcznej obrbki dlatego sprawd dwa razy zawarte informacje!',
    26 => '',
    27 => '',
    28 => 'Zaznacz tutaj aby usun obrazek',
    29 => 'cieka',
    30 => 'Import',
    31 => 'Nowi Uytkownicy',
    32 => 'Przetwarzanie zakoczone. Zaimportowano %d i napotkano %d bdw',
    33 => 'przelij',
    34 => 'Bd: Musisz poda plik do zaadowania.',
    35 => 'Ostatni Login',
    36 => '(nigdy)',
    37 => 'UID',
    38 => 'Group Listing',
    39 => 'Password (again)',
    40 => 'Registration Date',
    41 => 'Last login Date',
    42 => 'Banned',
    43 => 'Awaiting Activation',
    44 => 'Awaiting Authorization',
    45 => 'Active',
    46 => 'User Status',
    47 => 'Edit',
    48 => 'Show Admin Groups',
    49 => 'Admin Group',
    50 => 'Check to allow filtering this group as an Admin Use Group',
    51 => 'Online Days',
    52 => '<br' . XHTML . '>Note: "Online Days" is the number of days between the first registration and the last login.',
    53 => 'registered',
    54 => 'Batch Delete',
    55 => 'This only works if you have <code>$_CONF[\'lastlogin\'] = true;</code> in your config.php',
    56 => 'Please choose the type of user you want to delete and press "Update List". Then, uncheck those from the list you do not want to delete and press "Delete". Please note that you will only delete those that are currently visible in case the list spans over several pages.',
    57 => 'Phantom users',
    58 => 'Short-Time Users',
    59 => 'Old Users',
    60 => 'Users that registered more than ',
    61 => ' months ago, but never logged in.',
    62 => 'Users that registered more than ',
    63 => ' months ago, then logged in within 24 hours, but since then never came back to your site.',
    64 => 'Normal users, who simply did not visit your site since ',
    65 => ' months.',
    66 => 'Update List',
    67 => 'Months since registration',
    68 => 'Online Hours',
    69 => 'Offline Months',
    70 => 'could not be deleted',
    71 => 'sucessfully deleted',
    72 => 'No User selected for deletion',
    73 => 'Are You sure you want to permanently delete ALL selected users?',
    74 => 'Recent Users',
    75 => 'Users that registered in the last ',
    76 => ' months',
    77 => 'Email site login reminder to selected users',
    78 => 'Send Reminder',
    79 => 'No User selected for reminders',
    80 => 'Successfully sent Reminders',
    81 => 'Reminder to verify account for %s',
    82 => "Your account on {$_CONF['site_name']} has not been accesssed since %s and will be disabled if not accessed in the 30 days.",
    83 => "Your account on {$_CONF['site_name']} has not been used since it was created and will deleted soon if not accessed.",
    84 => "Your login name is: %s  for our site: {$_CONF['site_url']}",
    85 => 'If you have forgotten the password use the following link: %s',
    86 => 'Include',
    87 => 'Reminders',
    88 => 'Default Group',
    89 => 'Check to make this a default group for new users',
    90 => 'Apply "Default Group" change to existing user accounts'
);

###############################################################################
# admin/moderation.php

$LANG29 = array(
    1 => 'Zatwierd',
    2 => 'Kasuj',
    3 => 'Edytuj',
    4 => 'Profil',
    10 => 'Tytu',
    11 => 'Data Pocztkowa',
    12 => 'URL',
    13 => 'Kategoria',
    14 => 'Data',
    15 => 'Sekcja',
    16 => 'Nazwa uytkownika',
    17 => 'Pena nazwa uytkownika',
    18 => 'Email',
    34 => 'Panel Sterowania',
    35 => 'Przesane Artykuy',
    36 => 'Parent or Comment',
    37 => '',
    38 => 'Przelij',
    39 => 'adnych materiaw do zatwierdzenia',
    40 => 'Materiay przesane przez uytkownika',
    41 => 'Comment Submissions',
    42 => 'Username',
    43 => 'Auto-publish Comments?'
);

###############################################################################
# admin/mail.php

$LANG31 = array(
    1 => 'Mail',
    2 => 'Od',
    3 => 'Odpowiedz',
    4 => 'Temat',
    5 => 'Wiadomo',
    6 => 'Wylij do:',
    7 => 'Wszyscy',
    8 => 'Admin',
    9 => 'Opcje',
    10 => 'HTML',
    11 => 'Pilne!',
    12 => 'Wylij',
    13 => 'Zresetuj',
    14 => 'Ignoruj ustawienia uytkownika',
    15 => 'Bd podczas wysyania do: ',
    16 => 'Wiadomo wysana do: ',
    17 => "<a href={$_CONF['site_admin_url']}/mail.php>Wylij nastpn wiadomo</a>",
    18 => 'Do',
    19 => 'UWAGA: jeli chcesz wysa wiadomo do wszystkich uytkownikw, wybierz Logged-in Users z listy rozwijanej.',
    20 => "Wysanych <successcount> wiadomoci oraz <failcount> niewysanych wiadomoci.  Poniej szczegy dotyczce prby wysania kadej wiadomoci.  Moesz rwnie <a href=\"{$_CONF['site_admin_url']}/mail.php\">Wysa wiadomo</a> lub moesz <a href=\"{$_CONF['site_admin_url']}/moderation.php\">wrci do strony administracyjnej</a>.",
    21 => 'Bd',
    22 => 'Sukces',
    23 => 'Brak bdw',
    24 => 'Bez powodzenia',
    25 => '-- Wybierz Grup --',
    26 => 'Prosz uzupeni wszystkie pola i wybra grup z listy.'
);

###############################################################################
# admin/plugins.php

$LANG32 = array(
    1 => 'Instalowanie pluginw moe spowodowa uszkodzenie twojej instalacji Geekloga jak rwnie systemu.  Wane jest aby instalowa pluginy cignite z <a href="http://www.geeklog.net" target="_blank">Geeklog Homepage</a> poniewa s one szczegowo przez nas testowane na rnych systemach operacyjnych.  Wane aby mia wiadomo, e instalacja pluginu wymaga wykonania kilku komend filesystemu, co wie si z bezpieczestwem systemu, zwaszcza gdy pluginy pochodz od osb trzecich.  Pomimo tego ostrzeenia, nie gwarantujemy sukcesu instalacyjnego ani nie moemy by pocignici do odpowiedzialnoci za jakiekolwiek szkody wynike z instalacji jakiegokolwiek pluginu.  Instalacja na wasne ryzyko.  Instrukcje dotyczce rcznej instalacji pluginu znajduj si w kadym pakiecie z pluginem.',
    2 => 'Umowa Instalacyjna Pluginw',
    3 => 'Plugin Formularz Instalacyjny',
    4 => 'Plugin Plik',
    5 => 'Zainstalowane Pluginy',
    6 => 'Ostrzeenie: Plugin Ju Zainstalowany!',
    7 => 'Plugin, ktry prbujesz zainstalowa ju istnieje.  Prosz wykasowa istniejcy plugin i zainstalowa go ponownie',
    8 => 'Sprawdzanie Kompatybilnoci Pluginu Zakoczone Niepowodzeniem',
    9 => 'Ten plugin wymaga nowszej wersji Geekloga. Albo uaktualnij swoj kopi <a href=http://www.geeklog.net>Geekloga</a> albo cignij nowsz wersj tego pluginu.',
    10 => '<br' . XHTML . '><b>Brak zainstalowanych pluginw.</b><br' . XHTML . '><br' . XHTML . '>',
    11 => 'Aby zmodyfikowa lub wykasowa plugin, kliknij na nazw pluginu. Zobaczysz wicej informacji wcznie z adresem strony autora. Widoczne s wersje zainstalowana i wersja kodu. To pomoe stwierdzi czy dany plugin wymaga aktualizacji. Aby zainstalowa lub uaktualni dany plugin prosz zapozna si z doczon do niego instrukcj.',
    12 => 'brak nazwy pluginu dla plugineditor()',
    13 => 'Edytor Pluginw',
    14 => 'Nowy Plugin',
    15 => 'Panel Sterowania',
    16 => 'Nazwa',
    17 => 'Wersja',
    18 => 'Wersja GL',
    19 => 'Aktywny',
    20 => 'Tak',
    21 => 'Nie',
    22 => 'Instaluj',
    23 => 'Zapisz',
    24 => 'Anuluj',
    25 => 'Kasuj',
    26 => 'Nazwa Pluginu',
    27 => 'Strona Domowa Pluginu',
    28 => 'Wersja Zainstalowana',
    29 => 'Wersja GL',
    30 => 'Skasowa Plugin?',
    31 => 'Czy aby na pewno skasowa ten plugin?  Ta operacja usunie wszelkie pliki, dane i struktur uywane przez ten plugin.  Jeli chcesz kontynuwa kliknij kasuj poniej.',
    32 => '<p><b>Bdny format tagu AutoLink</b></p>',
    33 => 'Wersja Kodu',
    34 => 'Aktualizacja',
    35 => 'Edit',
    36 => 'Code',
    37 => 'Data',
    38 => 'Update!',
    39 => 'Upload a plugin',
    40 => 'You can upload a plugin archive (.tar.gz, .tgz, .zip) directly here:',
    41 => 'Upload',
    42 => 'Click to update',
    99 => 'An unknown error occured',
    100 => 'Ok.',
    101 => 'The uploaded file exceeds the upload_max_filesize directive in php.ini.',
    102 => 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form.',
    103 => 'The uploaded file was only partially uploaded.',
    104 => 'No file was uploaded.',
    105 => '(undefined error)',
    106 => 'Missing a temporary folder.',
    107 => 'Failed to write file to disk.',
    108 => 'File upload stopped by extension.'
);

###############################################################################
# admin/syndication.php

$LANG33 = array(
    1 => 'stwrz plik',
    2 => 'zapisz',
    3 => 'kasuj',
    4 => 'anuluj',
    10 => 'Syndykacja Treci',
    11 => 'Nowy Plik',
    12 => 'Panel Sterowania',
    13 => 'Aby zmodyfikowa lub usun plik, kliknij na tytu pliku poniej. Aby stworzy nowy plik, kliknij Nowy Plik powyej.',
    14 => 'Tytu',
    15 => 'Rodzaj',
    16 => 'Plik',
    17 => 'Format',
    18 => 'ost. aktualizacja',
    19 => 'Aktywny',
    20 => 'Tak',
    21 => 'Nie',
    22 => '<i>(plikw brak)</i>',
    23 => 'Wszystkie Artykuy',
    24 => 'Edytor Plikw',
    25 => 'Tytu Pliku',
    26 => 'Limit',
    27 => 'Dugo tekstu',
    28 => '(0 = bez tekstu, 1 = peny tekst, inne = ograniczona liczba znakw.)',
    29 => 'Opis',
    30 => 'Ost. Aktualizacja',
    31 => 'Kodowanie',
    32 => 'Jzyk',
    33 => 'Zawarto',
    34 => 'Tytuw',
    35 => 'Godzin',
    36 => 'Wybierz rodzaj pliku',
    37 => '',
    38 => 'Bd: Brakujce Pola',
    39 => 'Wpisz Tytu Pliku, Opis i Nazw Pliku.',
    40 => 'Prosz poda liczb tytuw lub czas w godzinach.',
    41 => 'Linki',
    42 => '',
    43 => 'All',
    44 => 'None',
    45 => 'Header-link in topic',
    46 => 'Limit Results',
    47 => 'Search',
    48 => 'Edit',
    49 => 'Feed Logo',
    50 => "Relative to site url ({$_CONF['site_url']})",
    51 => 'The filename you have chosen is already used by another feed. Please choose a different one.',
    52 => 'Error: existing Filename',
    53 => 'All Frontpage Stories',
    54 => 'Please select the type of feed to create.',
    55 => 'Articles'
);

###############################################################################
# confirmation and error messages

$MESSAGE = array(
    1 => "Haso zostao wysane i powiniene go wkrtce otrzyma. Postpuj zgodnie ze wskazwkami w wiadomoci. Dzikujemy za korzystanie z serwisu {$_CONF['site_name']}",
    2 => "Dzikujemy za przesanie artykuu do {$_CONF['site_name']}.  Otrzymali go nasi pracownicy do zatwierdzenia. Po zatwierdzeniu twj artyku bdzie dostpny dla innych uytkownikw naszego serwisu.",
    3 => '',
    4 => '',
    5 => 'Informacje dotyczce twojego konta zostay zapisane.',
    6 => 'Twoje preferencje dotyczce wygldu zostay zapisane.',
    7 => 'Twoje preferencje dotyczce komentarzy zostay zapisane.',
    8 => 'Zostae/a pomylnie wylogowany/a.',
    9 => 'Artyku zosta zapisany.',
    10 => 'Artyku zosta wykasowany.',
    11 => 'Blok zosta zapisany.',
    12 => 'Blok zosta wykasowany.',
    13 => 'Sekcja zostaa zapisana.',
    14 => 'Sekcja oraz wszystkie artykuy i bloki z ni zwizane zostay wykasowane.',
    15 => 'Your comment has been submitted for review and will be published when approved by a moderator.',
    16 => 'You have been unsubscribed. You will no longer be notified of new replies.',
    17 => '',
    18 => '',
    19 => '',
    20 => '',
    21 => 'Nowy uytkownik zosta zapisany.',
    22 => 'Nowy uytkownik zosta wykasowany.',
    23 => '',
    24 => '',
    25 => '',
    26 => '',
    27 => 'Wiadomo wysano.',
    28 => 'Plugin zosta zapisany',
    29 => 'Sorry, you do not have access to this administration page.  Please note that all attempts to access unauthorized features are logged',
    30 => 'Odmowa Dostpu',
    31 => '',
    32 => '',
    33 => '',
    34 => '',
    35 => '',
    36 => '',
    37 => '',
    38 => '',
    39 => '',
    40 => 'Komunikat Systemowy',
    41 => '',
    42 => '',
    43 => '',
    44 => 'Plugin zosta zainstalowany!',
    45 => 'Plugin zosta wykasowany.',
    46 => '',
    47 => '',
    48 => "Dziekujemy za zainteresowanie czonkowstwem w {$_CONF['site_name']}. Zweryfikujemy twoje zgoszenie i po zatwierdzeniu zostanie wysane haso pod podany adres e-mail.",
    49 => 'Twoja grupa zostaa zapisana.',
    50 => 'Grupa zostaa wykasowana.',
    51 => 'Ten login juz istnieje. Prosze wybrac inny.',
    52 => 'Podany adres email nie wyglada na prawidlowy.',
    53 => 'Twoje nowe haso zostao przyjte. Prosz zalogowac sie ponizej wpisujc nowe haso.',
    54 => 'Twoja proba o nowe haso wygasa. Prosz sprbowac ponownie poniej.',
    55 => 'Wkrtce powinien dotrze do Ciebie email. Postpuj zgodnie ze wskazwkami aby ustawi nowe haso dla Twojego konta.',
    56 => 'Podany adres email jest ju uywany.',
    57 => 'Twoje konto zostao pomylnie usunite.',
    58 => 'Plik zosta zapisany.',
    59 => 'Plik zosta skasowany.',
    60 => 'Plugin zosta pomylnie zaktualizowany',
    61 => 'Plugin %s: Nieznany komunikat placeholder',
    62 => 'The trackback comment has been deleted.',
    63 => 'An error occurred when deleting the trackback comment.',
    64 => 'Your trackback comment has been successfully sent.',
    65 => 'Weblog directory service successfully saved.',
    66 => 'The weblog directory service has been deleted.',
    67 => 'The new password does not match the confirmation password!',
    68 => 'You have to enter the correct current password.',
    69 => 'Your account has been blocked!',
    70 => 'Your account is awaiting administrator approval.',
    71 => 'Your account has now been confirmed and is awaiting administrator approval.',
    72 => 'An error occured while attempting to install the plugin. See error.log for details.',
    73 => 'An error occured while attempting to uninstall the plugin. See error.log for details.',
    74 => 'The pingback has been successfully sent.',
    75 => 'Trackbacks must be sent using a POST request.',
    76 => 'Do you really want to delete this item?',
    77 => 'WARNING:<br' . XHTML . '>You have set your default encoding to UTF-8. However, your server does not support multibyte encodings. Please install mbstring functions for PHP or choose a different character set/language.',
    78 => 'Please make sure that the email address and the confirmation email address are the same.',
    79 => 'The page you have been trying to open refers to a function that no longer exists on this site.',
    80 => 'The plugin that created this feed is currently disabled. You will not be able to edit this feed until you re-enable the parent plugin.',
    81 => 'You may have mistyped your login credentials.  Please try logging in again below.',
    82 => 'You have exceeded the number of allowed login attempts.  Please try again later.',
    83 => 'To change your password, email address, or for how long to remember you, please enter your current password.',
    84 => 'To delete your account, please enter your current password.',
    85 => 'There was a problem sending the email.',
    86 => 'The OpenID server invalidated your login attempt.',
    87 => 'OpenID login operation cancelled by user.',
    88 => 'The OpenID server returned an error.',
    89 => 'Unable to find an OpenID server for the given identity URL.',
    90 => 'OpenID identification cancelled.',
    91 => 'You specified an invalid identity URL.',
    92 => "Please <a href=\"{$_CONF['site_admin_url']}/sectest.php\">check the security of your site</a> before using it!",
    93 => 'Database back up was successful.',
    94 => 'Backup Failed: Filesize less than 1kb',
    95 => 'There was an error.',
    96 => '',
    97 => '',
    98 => 'The plugin was successfully uploaded.',
    99 => 'The plugin already exists.',
    100 => 'The plugin file you uploaded was not a GZip or Zip compressed archive.',
    101 => 'There are no topics (that you have access to). You need at least one topic to be able to submit stories.',
    400 => 'Not all required fields have been passed validation',
    401 => 'Please enter Fullname'
);

###############################################################################

$LANG_ACCESS = array(
    'access' => 'Dostp',
    'ownerroot' => 'Waciciel/Root',
    'group' => 'Grupa',
    'readonly' => 'Tylko-do-Odczytu',
    'accessrights' => 'Prawa Dostpu',
    'owner' => 'Waciciel',
    'grantgrouplabel' => 'Udziel Praw do Edycji Powyszej Grupie',
    'permmsg' => 'UWAGA: czonkowie to wszyscy zalogowani uytkownicy na stronie a anonimowi to wszyscy uytkownicy przegldajcy zawarto strony bez zalogowania.',
    'securitygroups' => 'Grupy Zabezpiecze',
    'editrootmsg' => "Pomimo tego, e jeste User Administrator, nie moesz edytowa gwnego uytkownka. Najpierw sam musisz zosta uytkownikiem gwnym.  Moesz edytowa pozostaych uytkownikw. Wszelkie nie autoryzowane prby edycji uytkownikw gwnych s logowane.  Powrt do strony Administracja Uytkownikami serwisu <a href=\"{$_CONF['site_admin_url']}/user.php\"></a>.",
    'securitygroupsmsg' => 'Zaznacz grupy do ktrych chcesz przypisa uytkownika.',
    'groupeditor' => 'Edytor Grup',
    'description' => 'Opis',
    'name' => 'Nazwa',
    'rights' => 'Uprawnienia',
    'missingfields' => 'Brakujce Pola',
    'missingfieldsmsg' => 'Musisz poda nazw i opis grupy',
    'groupmanager' => 'Menader Grup',
    'newgroupmsg' => 'Aby zmodyfikowa lub wykasowa grup kliknij na dan grup poniej. Aby stworzy now grup kliknij nowa grupa powyej. Grupy gwne nie mog by wykasowane s uywane przez system.',
    'groupname' => 'Nazwa Grupy',
    'coregroup' => 'Grupa Gwna',
    'yes' => 'Tak',
    'no' => 'Nie',
    'corerightsdescr' => "Ta grupa jest Gwn Grup strony {$_CONF['site_name']} .  Z tego wzgldu prawa dla  tej grupy nie mog by edytowane.  Poniej znajduje si lista do-odczytu praw tej grupy.",
    'groupmsg' => 'Grupy Zabezpiecze Groups w tym serwisie s hierarchiczne.  Poprzez dodanie tej grupy do jakiejkolwiek grupy poniej, tym samym nadasz tej grupie takie same prawa.  Jeeli to moliwe to zalecamy wykorzystanie poniszych grup przy nadawaniu praw jakiejkolwiek grupie.  Jeli chcesz nada tej grupie specjalne prawa, moesz wybra uprawnienia do rnych funkcji serwisu w poniszej sekcji \'Uprawnienia\'.  Aby doda t grup do ktrejkolwiek z poniszej listy, zaznacz po prostu wybran grup(y).',
    'coregroupmsg' => "To jest Grupa gwna serisu {$_CONF['site_name']}.  Z tego wzgldu grupy nalece do tej kategorii nie mog by edytowane.  Poniej znajduje si lista, tylko do odczytu, grup z tej kategorii.",
    'rightsdescr' => 'Dostp grupowy to wybranych uprawnie poniej moe by nadany bezporednio danej grupie LUB innej grupie, do ktrej dana grupa naley.  Te z listy poniej bez pola wyboru oznaczaj uprawnienia tej grupy wynikajce z faktu przynalenoci do grupy z danym uprawnieniem.  Uprawnienia z polami wyboru mog zosta bezporednio nadane danej grupie.',
    'lock' => 'Blokada',
    'members' => 'Czonkowie',
    'anonymous' => 'Anonim',
    'permissions' => 'Uprawnienia',
    'permissionskey' => 'R = odczyt, E = edycja, prawa do edycji zakadaj prawa do odczytu',
    'edit' => 'Edycja',
    'none' => 'Brak',
    'accessdenied' => 'Odmowa Dostpu',
    'storydenialmsg' => "Brak dostpu do tego artykuu.  Prawdopodobnie nie jeste czonkiem serwisu {$_CONF['site_name']}.  Zapraszamy do <a href=\"{$_CONF['site_url']}/users.php?mode=new\" rel=\"nofollow\"> czonkostwa</a> w serwisie {$_CONF['site_name']} aby otrzyma peny dostp!",
    'nogroupsforcoregroup' => 'Grupa nie naley do pozostaych grup',
    'grouphasnorights' => 'Grupa nie ma dostpu do adnych funkcji administracyjnych tego serwisu',
    'newgroup' => 'Nowa Grupa',
    'adminhome' => 'Panel Sterowania',
    'save' => 'zapisz',
    'cancel' => 'anuluj',
    'delete' => 'kasuj',
    'canteditroot' => 'Wystpia prba edycji grupy Gwnej. Niestety nie naleysz do adnej z grup Gwnych dlatego nie masz dostpu do tej grupy.  Skontaktuj si z administratorem systemu jeli uwaasz, e to pomyka',
    'listusers' => 'Listuj Uytkownikw',
    'listthem' => 'listuj',
    'usersingroup' => 'Uytkownicy w grupie %s',
    'usergroupadmin' => 'Administracja Grupami Uytkownikw',
    'add' => 'Dodaj',
    'remove' => 'Usu',
    'availmembers' => 'Dostpni Czonkowie',
    'groupmembers' => 'Czonkowie Grupy',
    'canteditgroup' => 'Aby wyedytowa t grup musisz do niej nalee. Prosz skontaktowa si z administratorem jeli uwaasz, e nastpia pomyka.',
    'cantlistgroup' => 'Aby zobaczy czonkw tej grupy, musisz by jej czonkiem. Skontaktuj si z administratorem jeli uwaasz, e to jest bd.',
    'editgroupmsg' => 'To modify the group membership, click on the member names(s) and use the add or remove buttons. If the member is a member of the group, their name will appear on the right side only. Once you are complete - press <b>Save</b> to update the group and return to the main group admin page.',
    'listgroupmsg' => 'Listing of all current members in the group: <b>%s</b>',
    'search' => 'Search',
    'submit' => 'Submit',
    'limitresults' => 'Limit Results',
    'group_id' => 'Group ID',
    'plugin_access_denied_msg' => 'You are illegally trying access a plugin administration page.  Please note that all attempts to illegally access this page are logged.',
    'groupexists' => 'Group name already exists',
    'groupexistsmsg' => 'There is already a group with this name. Group names must be unique.'
);

###############################################################################
# admin/database.php

$LANG_DB_BACKUP = array(
    'last_ten_backups' => '10 Kopii Zapasowych',
    'do_backup' => 'Wykonaj Kopi Zapasow',
    'backup_successful' => 'Kopia bazy wykonana pomylnie.',
    'db_explanation' => 'Aby wykona now kopi zapasow twojego systemu, kliknij poniszy przycisk',
    'not_found' => "Niewaciwa cieka lub program archiwizujcy nie jest wykonywalny.<br" . XHTML . ">Sprawd <strong>\$_DB_mysqldump_path</strong> ustawienia w config.php.<br" . XHTML . ">Zmienna jest obecnie ustawiona na: <var>{$_DB_mysqldump_path}</var>",
    'zero_size' => 'Wykonanie Kopii Nie Powiodo Si: Rozmiar pliku 0 bajtw',
    'path_not_found' => "{$_CONF['backup_path']} nie istnieje lub nie jest katalogiem",
    'no_access' => "BD: Katalog {$_CONF['backup_path']} jest niedostpny.",
    'backup_file' => 'Plik kopii',
    'size' => 'Rozmiar',
    'bytes' => 'Bajtw',
    'total_number' => 'Wszystkich kopii bezpieczestwa: %d',
    'download' => 'Click to download this file',
    'new_backup' => 'New Backup',
    'delete_failure' => 'One or more backup files could not be deleted.',
    'delete_success' => 'Backup file(s) successfully deleted.',
    'convert_menu' => 'Convert to InnoDB',
    'convert_title' => 'Convert to InnoDB tables',
    'convert_button' => 'Convert',
    'sorry_no_innodb' => 'Sorry, your version of MySQL does not support InnoDB tables.',
    'innodb_explain' => 'InnoDB tables provide better performance on <em>really</em> large databases but make the backup process more complicated. Please <a href="http://dev.mysql.com/doc/mysql/en/innodb.html">read up</a> on the pros and cons of InnoDB tables before you perform this operation.',
    'already_converted' => 'Note: It appears that all of the tables have already been converted to InnoDB.',
    'conversion_patience' => 'Note: Conversion may take some time - please be patient.',
    'innodb_success' => 'Successfully converted tables to InnoDB.',
    'table_issues' => 'There may have been problems with some tables, though. Please check error.log for details.',
    'optimize_menu' => 'Optimize Tables',
    'optimize_title' => 'Optimize Tables',
    'optimize_button' => 'Optimize',
    'optimize_explain' => 'Optimizing tables may help to improve the performance of your site. The actual impact depends on the table usage and some tables may benefit from it more than others. Do no expect to see a huge difference in performance. The <a href="http://dev.mysql.com/doc/mysql/en/optimize-table.html">MySQL manual</a> states: <q>it is not likely that you need to do this more than once a week or month</q>.',
    'last_optimization' => 'Last optimization',
    'optimization_patience' => 'Note: Optimization may take some time - please be patient.',
    'optimize_success' => 'Successfully optimized database tables.'
);

###############################################################################

$LANG_BUTTONS = array(
    1 => 'Gwna',
    2 => 'Kontakt',
    3 => 'Napisz Artyku',
    4 => '',
    5 => '',
    6 => '',
    7 => 'Statystyka',
    8 => 'Osobiste',
    9 => 'Szukaj',
    10 => 'zaawansowane szukanie',
    11 => 'Directory'
);

###############################################################################
# 404.php

$LANG_404 = array(
    1 => 'Bd 404',
    2 => 'Kurcze, wszdzie szukaem ale nie mog znale <b>%s</b>.',
    3 => "<p>Przykro nam ale dany plik nie istnieje. Sprawd <a href=\"{$_CONF['site_url']}/search.php\">stron z wyszukiwark</a> aby sprawdzi czy mona znale co zgubie."
);

###############################################################################
# login form

$LANG_LOGIN = array(
    1 => 'Wymagany jest login',
    2 => 'Sorry, aby wej na te strony musisz by zalogowany.',
    3 => 'Login',
    4 => 'Nowy Uytkownik'
);

###############################################################################
# trackback.php

$LANG_TRB = array(
    'trackback' => 'Trackback',
    'from' => 'from',
    'tracked_on' => 'Tracked on',
    'read_more' => '[read more]',
    'intro_text' => 'Here\'s what others have to say about \'%s\':',
    'no_comments' => 'No trackback comments for this entry.',
    'this_trackback_url' => 'Trackback URL for this entry:',
    'num_comments' => '%d trackback comments',
    'send_trackback' => 'Send Pings',
    'preview' => 'Preview',
    'editor_title' => 'Send trackback comment',
    'trackback_url' => 'Trackback URL',
    'entry_url' => 'Entry URL',
    'entry_title' => 'Entry Title',
    'blog_name' => 'Site Name',
    'excerpt' => 'Excerpt',
    'truncate_warning' => 'Note: The receiving site may truncate your excerpt',
    'button_send' => 'Send',
    'button_preview' => 'Preview',
    'send_error' => 'Error',
    'send_error_details' => 'Error when sending trackback comment:',
    'url_missing' => 'No Entry URL',
    'url_required' => 'Please enter at least a URL for the entry.',
    'target_missing' => 'No Trackback URL',
    'target_required' => 'Please enter a trackback URL',
    'error_socket' => 'Could not open socket.',
    'error_response' => 'Response not understood.',
    'error_unspecified' => 'Unspecified error.',
    'select_url' => 'Select Trackback URL',
    'not_found' => 'Trackback URL not found',
    'autodetect_failed' => 'Geeklog could not detect the Trackback URL for the post you want to send your comment to. Please enter it manually below.',
    'trackback_explain' => 'From the links below, please select the URL you want to send your Trackback comment to. Geeklog will then try to determine the correct Trackback URL for that post. Or you can <a href="%s">enter it manually</a> if you know it already.',
    'no_links_trackback' => 'No links found. You can not send a Trackback comment for this entry.',
    'pingback' => 'Pingback',
    'pingback_results' => 'Pingback results',
    'send_pings' => 'Send Pings',
    'send_pings_for' => 'Send Pings for "%s"',
    'no_links_pingback' => 'No links found. No Pingbacks were sent for this entry.',
    'pingback_success' => 'Pingback sent.',
    'no_pingback_url' => 'No pingback URL found.',
    'resend' => 'Resend',
    'ping_all_explain' => 'You can now notify the sites you linked to (<a href="http://en.wikipedia.org/wiki/Pingback">Pingback</a>), advertise that your site has been updated by pinging weblog directory services, or send a <a href="http://en.wikipedia.org/wiki/Trackback">Trackback</a> comment in case you wrote about a post on someone else\'s site.',
    'pingback_button' => 'Send Pingback',
    'pingback_short' => 'Send Pingbacks to all sites linked from this entry.',
    'pingback_disabled' => '(Pingback disabled)',
    'ping_button' => 'Send Ping',
    'ping_short' => 'Ping weblog directory services.',
    'ping_disabled' => '(Ping disabled)',
    'trackback_button' => 'Send Trackback',
    'trackback_short' => 'Send a Trackback comment.',
    'trackback_disabled' => '(Trackback disabled)',
    'may_take_a_while' => 'Please note that sending Pingbacks and Pings may take a while.',
    'ping_results' => 'Ping results',
    'unknown_method' => 'Unknown ping method',
    'ping_success' => 'Ping sent.',
    'error_site_name' => 'Please enter the site\'s name.',
    'error_site_url' => 'Please enter the site\'s URL.',
    'error_ping_url' => 'Please enter a valid Ping URL.',
    'no_services' => 'No weblog directory services configured.',
    'services_headline' => 'Weblog Directory Services',
    'service_explain' => 'To modify or delete a weblog directory service, click on the edit icon of that service below. To add a new weblog directory service, click on "Create New" above.',
    'service' => 'Service',
    'ping_method' => 'Ping method',
    'service_website' => 'Website',
    'service_ping_url' => 'URL to ping',
    'ping_standard' => 'Standard Ping',
    'ping_extended' => 'Extended Ping',
    'ping_unknown' => '(unknown method)',
    'edit_service' => 'Edit Weblog Directory Service',
    'trackbacks' => 'Trackbacks',
    'editor_intro' => 'Prepare your trackback comment for <a href="%s">%s</a>.',
    'editor_intro_none' => 'Prepare your trackback comment.',
    'trackback_note' => 'To send a trackback comment for a story, go to the list of stories and click on "Send Ping" for the story. To send a trackback that is not related to a story, <a href="%s">click here</a>.',
    'pingback_explain' => 'Enter a URL to send the Pingback to. The pingback will point to your site\'s homepage.',
    'pingback_url' => 'Pingback URL',
    'site_url' => 'This site\'s URL',
    'pingback_note' => 'To send a pingback for a story, go to the list of stories and click on "Send Ping" for the story. To send a pingback that is not related to a story, <a href="%s">click here</a>.',
    'pbtarget_missing' => 'No Pingback URL',
    'pbtarget_required' => 'Please enter a pingback URL',
    'pb_error_details' => 'Error when sending the pingback:',
    'delete_trackback' => 'To delete this Trackback click: '
);

###############################################################################
# directory.php

$LANG_DIR = array(
    'title' => 'Article Directory',
    'title_year' => 'Article Directory for %d',
    'title_month_year' => 'Article Directory for %s %d',
    'nav_top' => 'Back to Article Directory',
    'no_articles' => 'No articles.'
);

###############################################################################
# admin/sectest.php

$LANG_SECTEST = array(
    'sectest' => 'Geeklog Security Check',
    'results' => 'Results of the Security Check',
    'okay' => 'Everything seems to be in order.',
    'please_fix' => 'Please fix the above issues before using your site!',
    'please_note' => 'Please note that no site is ever 100% secure. This script can only test for obvious security issues.',
    'stay_informed' => 'To stay informed about new Geeklog releases and possible security issues, we suggest that you subscribe to the (low-traffic) %s mailing list and/or use the %s option in your Admin menu from time to time to check for available updates.',
    'public_html' => '"public_html" should never be part of your site\'s URL.  Please read the part about public_html in the %s again and change your setup accordingly before you proceed.',
    'installation' => 'installation instructions',
    'directory' => 'directory',
    'failed_tmp' => 'Failed to create a temporary file in your %s directory. Check your directory permissions!',
    'fix_it' => 'This is a security risk and should be fixed!',
    'reachable' => 'Your %s is reachable from the web.',
    'not_reachable' => 'Good! Your %s is not reachable from the web.',
    'not_sure' => 'Got an HTTP result code %s when trying to test your %s. Not sure what to make of it ...',
    'remove_inst' => 'You should really remove the install directory %s once you have your site up and running without any errors.',
    'remove_inst2' => 'Keeping it around would allow malicious users the ability to destroy your current install, take over your site, or retrieve sensitive information.',
    'inst_removed' => 'Good! You seem to have removed the install directory already.',
    'fix_password' => 'You still have not changed the <strong>default password</strong> from "password" on %s Root user account(s).',
    'password_okay' => 'Good! You seem to have changed the default account password already.'
);

###############################################################################
# "What's New" Time Strings
# 
# For the first two strings, you can use the following placeholders.
# Order them so it makes sense in your language:
# %i    item, "Stories"
# %n    amount, "2", "20" etc.
# %t    time, "2" (weeks)
# %s    scale, "hrs", "weeks"

$LANG_WHATSNEW = array(
    'new_string' => '%n new %i in the last %t %s',
    'new_last' => 'last %t %s',
    'minutes' => 'minutes',
    'hours' => 'hours',
    'days' => 'days',
    'weeks' => 'weeks',
    'months' => 'months',
    'minute' => 'minute',
    'hour' => 'hour',
    'day' => 'day',
    'week' => 'week',
    'month' => 'month'
);

###############################################################################
# Month names

$LANG_MONTH = array(
    1 => 'Stycze',
    2 => 'Luty',
    3 => 'Marzec',
    4 => 'Kwiecie',
    5 => 'Maj',
    6 => 'Czerwiec',
    7 => 'Lipiec',
    8 => 'Sierpie',
    9 => 'Wrzesie',
    10 => 'Padziernik',
    11 => 'Listopad',
    12 => 'Grudzie'
);

###############################################################################
# Weekdays

$LANG_WEEK = array(
    1 => 'Niedziela',
    2 => 'Poniedziaek',
    3 => 'Wtorek',
    4 => 'roda',
    5 => 'Czwartek',
    6 => 'Pitek',
    7 => 'Sobota'
);

###############################################################################
# Admin - Strings
# 
# These are some standard strings used by core functions as well as plugins to
# display administration lists and edit pages

$LANG_ADMIN = array(
    'search' => 'Search',
    'limit_results' => 'Limit Results',
    'submit' => 'Submit',
    'edit' => 'Edit',
    'edit_adv' => 'Adv. Edit',
    'admin_home' => 'Admin Home',
    'create_new' => 'Create New',
    'create_new_adv' => 'Create New (Adv.)',
    'enabled' => 'Enabled',
    'title' => 'Title',
    'page_title' => 'Page Title',
    'type' => 'Type',
    'topic' => 'Topic',
    'help_url' => 'Help File URL',
    'save' => 'Save',
    'cancel' => 'Cancel',
    'delete' => 'Delete',
    'delete_sel' => 'Delete selected',
    'copy' => 'Copy',
    'no_results' => '- No entries found -',
    'data_error' => 'There was an error processing the subscription data. Please check the data source.',
    'preview' => 'Preview',
    'records_found' => 'Records found',
    'addchild' => 'Add child',
    'list' => 'list',
    'list_all' => 'List all',
    'meta_description' => 'Meta Description',
    'meta_keywords' => 'Meta Keywords',
    'na' => 'N/A',
    'token_expiry' => 'You have until %s to make changes. After that time, the security token embedded into this page will expire and you will lose your changes.',
    'token_expired' => 'The security token for this operation has expired. Please authenticate again to continue.',
    'reauth_msg' => 'The security token for this operation has expired. If you want to continue with this operation, then please authenticate again below. This will ensure that the changes you just made will not be lost.',
    'authenticate' => 'Authenticate'
);

# Localisation of the texts for the various drop-down menus that are actually
# stored in the database. If these exist, they override the texts from the
# database.

$LANG_commentcodes = array(
    0 => 'Comments Enabled',
    -1 => 'Comments Disabled',
    1 => 'Comments Closed'
);

$LANG_commentmodes = array(
    'flat' => 'Flat',
    'nested' => 'Nested',
    'threaded' => 'Threaded',
    'nocomment' => 'No Comments'
);

$LANG_cookiecodes = array(
    0 => '(don\'t)',
    3600 => '1 Hour',
    7200 => '2 Hours',
    10800 => '3 Hours',
    28800 => '8 Hours',
    86400 => '1 Day',
    604800 => '1 Week',
    2678400 => '1 Month'
);

$LANG_dateformats = array(
    0 => 'System Default'
);

$LANG_featurecodes = array(
    0 => 'Not Featured',
    1 => 'Featured'
);

$LANG_frontpagecodes = array(
    0 => 'Show Only in Topic',
    1 => 'Show on Front Page'
);

$LANG_postmodes = array(
    'plaintext' => 'Plain Old Text',
    'html' => 'HTML Formatted'
);

$LANG_sortcodes = array(
    'ASC' => 'Oldest First',
    'DESC' => 'Newest First'
);

$LANG_trackbackcodes = array(
    0 => 'Trackback Enabled',
    -1 => 'Trackback Disabled'
);

###############################################################################
# Localization of the Admin Configuration UI

$LANG_CONFIG = array(
    'home' => 'Home',
    'admin_home' => 'Site Administration',
    'sections' => 'Configuration Sections',
    'restore' => 'Restore',
    'add_element' => 'Add Element',
    'save_changes' => 'Zapisz zmiany',
    'reset_form' => 'Resetuj zmiany',
    'changes_made' => 'Changes were successfully made to',
    'title' => 'Menader ustawie',
    'disable' => 'Kliknij aby wyczy t opcj',
    'enable' => 'Enable'
);

$LANG_configsections['Core'] = array(
    'label' => 'Geeklog',
    'title' => 'Konfiguracja Geeklog-a'
);

$LANG_confignames['Core'] = array(
    'path_html' => 'cieka HTML',
    'site_url' => 'Adres URL',
    'site_admin_url' => 'Adres panelu administracyjnego',
    'site_mail' => 'E-Mail strony',
    'noreply_mail' => 'E-Mail w jedn stron',
    'site_name' => 'Nazwa strony',
    'site_slogan' => 'Slogan',
    'microsummary_short' => 'Mikro streszczenie',
    'path_log' => 'Log',
    'path_language' => 'Jzyk',
    'backup_path' => 'Kopia zapasowa',
    'path_data' => 'Dane',
    'path_images' => 'Zdjcia',
    'path_pear' => 'cieka do Pear',
    'have_pear' => 'Czy jest biblioteka Pear?',
    'mail_settings' => 'Ustawienia poczty',
    'allow_mysqldump' => 'Zezwalaj na zrzut MySQL',
    'mysqldump_path' => 'cieka do plikw wykonawczych',
    'mysqldump_options' => 'Opcje zrzutu MySQL',
    'mysqldump_filename_mask' => 'Backup File Name Mask',
    'theme' => 'Layout',
    'doctype' => 'DOCTYPE Declaration',
    'menu_elements' => 'Elementy Menu',
    'path_themes' => 'cieka do katalogu z layoutami',
    'disable_new_user_registration' => 'Wycz rejestracj nowych uytkownikw',
    'allow_user_themes' => 'Uytkownik moe zmienia layout',
    'allow_user_language' => 'Uytkownik moe zmienia jzyk',
    'allow_user_photo' => 'Uytkownik moe doda swoje zdjcie',
    'allow_username_change' => 'Uytkownik moe zmieni nazw konta',
    'allow_account_delete' => 'Uytkownik moe usun swoje',
    'hide_author_exclusion' => 'Zezwalaj na ukrycie autora',
    'show_fullname' => 'Poka pen nazw uytkwonika',
    'show_servicename' => 'Pokazuj nazw usugi',
    'custom_registration' => 'Wcz wasn rejestracj',
    'user_login_method' => 'Metoda logowania uytkownika',
    'spamx' => 'Spam-X ustawienia',
    'sort_admin' => 'Sortowanie odnonikw',
    'language' => 'Jzyk',
    'locale' => 'Opcje regionalne',
    'date' => 'Format Daty',
    'daytime' => 'Format daty dziennej',
    'shortdate' => 'Format daty krtkiej',
    'dateonly' => 'Tylko data - format',
    'timeonly' => 'Tylko godzina - format',
    'week_start' => 'Pocztek Tygodnia',
    'hour_mode' => 'Tryb godzinowy',
    'thousand_separator' => 'Separator tysiczny',
    'decimal_separator' => 'Separator dziesitny',
    'decimal_count' => 'Liczenie dziesitne',
    'language_files' => 'Pliki jzykowe',
    'languages' => 'Jzyki',
    'timezone' => 'Strefa czasowa',
    'site_disabled_msg' => 'Komunikat lub odnonik podczas wyczenia strony',
    'rootdebug' => 'Root Debugging',
    'cookie_session' => 'Nazwa ciasteczka sesji',
    'cookie_name' => 'Nazwa ciasteczka staego',
    'cookie_password' => 'Nazwa ciasteczka z hasem',
    'cookie_theme' => 'Nazwa ciasteczka layoutu',
    'cookie_language' => 'Nazwa ciasteczka jzykowego',
    'cookie_tzid' => 'Nazwa ciasteczka strefy czasowej',
    'cookie_anon_name' => 'Anon. Username Cookie Name',
    'cookie_ip' => 'Czy ciasteczko ma zawiera adres IP?',
    'default_perm_cookie_timeout' => 'Stae wyganicie',
    'session_cookie_timeout' => 'Wyganicie sesji',
    'cookie_path' => 'cieka ciasteczek',
    'cookiedomain' => 'Domena ciasteczek',
    'cookiesecure' => 'Cookie Secure',
    'lastlogin' => 'Zarejestrowa ostatnie logowanie?',
    'num_search_results' => 'Liczba wynikw z wyszukiwarki',
    'loginrequired' => 'Wymagane zalogowanie?',
    'submitloginrequired' => 'Wymagane zalogowanie do przesania materiaw?',
    'commentsloginrequired' => 'Wymagane zalogowanie do skomentowania?',
    'statsloginrequired' => 'Wymagane zalogowanie do przegldania statystyk?',
    'searchloginrequired' => 'Search Login Required?',
    'profileloginrequired' => 'Profile Login Required?',
    'emailuserloginrequired' => 'E-Mail User Login Required?',
    'emailstoryloginrequired' => 'E-Mail Story Login Required?',
    'directoryloginrequired' => 'Directory Login Required?',
    'storysubmission' => 'Story Submission Queue?',
    'usersubmission' => 'User Submission Queue?',
    'listdraftstories' => 'List Draft Stories?',
    'notification' => 'Notifications',
    'postmode' => 'Default Post Mode',
    'speedlimit' => 'Post Speed Limit',
    'skip_preview' => 'Skip Preview in Posts',
    'advanced_editor' => 'Advanced Editor?',
    'wikitext_editor' => 'Wikitext Editor?',
    'cron_schedule_interval' => 'Cron Schedule Interval',
    'sortmethod' => 'Sort Topics',
    'showstorycount' => 'Show Story Count?',
    'showsubmissioncount' => 'Show Submission Count?',
    'hide_home_link' => 'Hide Home Link?',
    'whosonline_threshold' => 'Session Threshold',
    'whosonline_anonymous' => 'Hide Names from Guests?',
    'emailstories' => 'Daily Digest Enabled?',
    'emailstorieslength' => 'Length of Stories',
    'emailstoriesperdefault' => 'Enable for New Users?',
    'allow_domains' => 'Automatic Allow Domains',
    'disallow_domains' => 'Automatic Disallow Domains',
    'newstoriesinterval' => 'New Stories Interval',
    'newcommentsinterval' => 'New Comments Interval',
    'newtrackbackinterval' => 'New Trackbacks Interval',
    'hidenewstories' => 'Hide New Stories',
    'hidenewcomments' => 'Hide New Comments',
    'hidenewtrackbacks' => 'Hide New Trackbacks',
    'hidenewplugins' => 'Hide New Plugin Entries',
    'title_trim_length' => 'Title Trim Length',
    'trackback_enabled' => 'Trackback Enabled?',
    'pingback_enabled' => 'Pingback Enabled?',
    'ping_enabled' => 'Ping Enabled?',
    'trackback_code' => 'Trackback Default',
    'multiple_trackbacks' => 'Multiple Trackbacks',
    'trackbackspeedlimit' => 'Trackback Speed Limit',
    'check_trackback_link' => 'Check Trackbacks',
    'pingback_self' => 'Pingback Self?',
    'pingback_excerpt' => 'Create Pingback Excerpt?',
    'link_documentation' => 'Link to Documentation?',
    'link_versionchecker' => 'Link to Version Checker?',
    'maximagesperarticle' => 'Maks. liczba zdj w artykule',
    'limitnews' => 'Liczba artykuw na stron',
    'minnews' => 'Min. liczba artykuw na stron',
    'contributedbyline' => 'Poka "Autor"?"',
    'hideviewscount' => 'Ukryj liczb odson?',
    'hideemailicon' => 'Ukryj ikon emaila?',
    'hideprintericon' => 'Ukryj ikon drukowania?',
    'allow_page_breaks' => 'Zezwalaj na amanie stron?',
    'page_break_comments' => 'Komentarze dla artykuw wielostronicowych',
    'article_image_align' => 'Wyrwnywanie ikon sekcji',
    'show_topic_icon' => 'Poka ikon sekcji?',
    'draft_flag' => 'Draft Flag Default',
    'frontpage' => 'Frontpage Default',
    'hide_no_news_msg' => 'Hide "No News" Message?',
    'hide_main_page_navigation' => 'Hide Main Page Navigation?',
    'onlyrootfeatures' => 'Only Root can Feature?',
    'aftersave_story' => 'Po zapisaniu artykuu',
    'aftersave_user' => 'Po zapisaniu uytkownika',
    'show_right_blocks' => 'Zawsze pokazuj prawe bloki?',
    'showfirstasfeatured' => 'Poka pierwszy artyku jako Artyku Dnia?',
    'backend' => 'Wcz kanay RSS?',
    'rdf_file' => 'Katalog z plikami do syndykacji treci',
    'rdf_limit' => 'Limit kanaw RSS',
    'rdf_storytext' => 'Dugo artykuu w pliku RSS',
    'rdf_language' => 'Jzyk kanau RSS',
    'syndication_max_headlines' => 'Maks. liczba tytuw (bloki portalowe)',
    'copyrightyear' => 'Prawa Autorskie Rok',
    'image_lib' => 'Image Library',
    'path_to_mogrify' => 'Path to Mogrify',
    'path_to_netpbm' => 'Path to Netpbm',
    'debug_image_upload' => 'Debug Image Uploading?',
    'keep_unscaled_image' => 'Keep Unscaled Image?',
    'allow_user_scaling' => 'Allow User Scaling?',
    'jpeg_quality' => 'JPEG Quality?',
    'max_image_width' => 'Max Image Width?',
    'max_image_height' => 'Max Image Height?',
    'max_image_size' => 'Max Image Size?',
    'max_topicicon_width' => 'Max Topic Icon Width?',
    'max_topicicon_height' => 'Max Topic Icon Height?',
    'max_topicicon_size' => 'Max Topic Icon Size?',
    'max_photo_width' => 'Max Photo Width?',
    'max_photo_height' => 'Max Photo Height?',
    'max_photo_size' => 'Max Photo Size?',
    'use_gravatar' => 'Use Gravatar?',
    'gravatar_rating' => 'Gravatar Rating',
    'force_photo_width' => 'Force Photo Width',
    'default_photo' => 'Default Photo',
    'commentspeedlimit' => 'Comment Speed Limit',
    'comment_limit' => 'Comment Limit',
    'comment_mode' => 'Comment Mode',
    'comment_code' => 'Comment Default',
    'comment_edit' => 'Allow Comment Edit?',
    'comment_edittime' => 'Comment Edit Time (seconds)',
    'commentsubmission' => 'Queue Comment Submissions',
    'passwordspeedlimit' => 'Password Speed Limit',
    'login_attempts' => 'Max. Login Attempts',
    'login_speedlimit' => 'Login Speed Limit',
    'user_html' => 'User HTML',
    'admin_html' => 'Admin HTML',
    'advanced_html' => 'Additional HTML for Adv. Editor',
    'skip_html_filter_for_root' => 'Skip HTML Filter for Root?',
    'allowed_protocols' => 'Allowed Protocols',
    'disable_autolinks' => 'Disable Autotags?',
    'clickable_links' => 'Make URLs clickable?',
    'compressed_output' => 'Send compressed output?',
    'frame_options' => 'Protection against "clickjacking"',
    'censormode' => 'Censor Mode?',
    'censorreplace' => 'Censor Replace Text',
    'censorlist' => 'Censor List',
    'ip_lookup' => 'IP Lookup',
    'url_rewrite' => 'Wcz przyjazne adresy URL',
    'meta_tags' => 'Meta Tags',
    'meta_description' => 'Default Meta Description',
    'meta_keywords' => 'Default Meta Keywords',
    'default_permissions_block' => 'Block Default Permissions',
    'default_permissions_story' => 'Story Default Permissions',
    'default_permissions_topic' => 'Topic Default Permissions',
    'atom_max_stories' => 'Max. Stories in Webservices Feed',
    'disable_webservices' => 'Disable Webservices?',
    'restrict_webservices' => 'Restrict Webservices?',
    'article_comment_close_enabled' => 'Automatically close comments (default)',
    'article_comment_close_days' => 'Days to close comments (default)',
    'comment_close_rec_stories' => 'Number of most recent stories enabled for comments',
    'allow_reply_notifications' => 'Allow comment reply notifications?',
    'search_style' => 'Results List Style',
    'search_limits' => 'Page Limits',
    'search_show_num' => 'Show Result Number?',
    'search_show_type' => 'Show Result Type?',
    'search_show_sort' => 'Allow User to Sort Results?',
    'search_show_limit' => 'Show Page Limits?',
    'search_separator' => 'Group Separator',
    'search_def_keytype' => 'Default Search Method',
    'search_def_sort' => 'Default Sort Order'
);

$LANG_configsubgroups['Core'] = array(
    'sg_site' => 'Strona',
    'sg_stories' => 'Artykuy i Powiadomienia Zwrotne',
    'sg_theme' => 'Layout',
    'sg_blocks' => 'Bloki',
    'sg_users' => 'Uytkownicy i Przesane materiay',
    'sg_images' => 'Zdjcia',
    'sg_locale' => 'Jzyki i Ustawienia regionalne',
    'sg_misc' => 'Rne'
);

$LANG_fs['Core'] = array(
    'fs_site' => 'Strona',
    'fs_paths' => 'cieki',
    'fs_theme' => 'Layout',
    'fs_mail' => 'Poczta',
    'fs_pear' => 'Pear',
    'fs_mysql' => 'MySQL',
    'fs_users' => 'Uytkownicy',
    'fs_misc' => 'Rne',
    'fs_spamx' => 'Spam-X',
    'fs_admin_block' => 'Admin Block',
    'fs_locale' => 'Ustawienia regionalne',
    'fs_language' => 'Jzyk',
    'fs_debug' => 'Debug',
    'fs_cookies' => 'Ciasteczka',
    'fs_login' => 'Ustawienia logowania',
    'fs_search' => 'Szukaj',
    'fs_user_submission' => 'Materiay uytkownikw',
    'fs_submission' => 'Ustawienia przesyania materiaw',
    'fs_topics_block' => 'Blok sekcji',
    'fs_whosonline_block' => 'Who\'s Online Block',
    'fs_daily_digest' => 'Daily Digest',
    'fs_whatsnew_block' => 'Nowoci',
    'fs_trackback' => 'Trackback',
    'fs_pingback' => 'Pingback',
    'fs_story' => 'Artyku',
    'fs_theme_advanced' => 'Ustawienia zaawansowane',
    'fs_syndication' => 'Syndykacja treci',
    'fs_imagelib' => 'Katalog zdj',
    'fs_upload' => 'aduj',
    'fs_articleimg' => 'Zdjcia w artykuach',
    'fs_topicicon' => 'Ikony sekcji',
    'fs_userphoto' => 'Zdjcia',
    'fs_gravatar' => 'Gravatar',
    'fs_comments' => 'Komentarze',
    'fs_htmlfilter' => 'Filtrowanie HTML',
    'fs_censoring' => 'Cenzura',
    'fs_iplookup' => 'Podgld IP',
    'fs_perm_story' => 'Domylne ustawienia dla artykuw',
    'fs_perm_topic' => 'Domylne ustawienia dla sekcji',
    'fs_perm_block' => 'Domylne ustawienia dla blokw',
    'fs_webservices' => 'Usugi WWW'
);

$LANG_configselects['Core'] = array(
    0 => array('Tak' => 1, 'Nie' => 0),
    1 => array('Tak' => true, 'Nie' => false),
    2 => array('Odrzu' => 0, 'Tylko Najnowsze' => 1, 'Zezwalaj na Wiele Postw' => 2),
    3 => array('Trackback Wczony' => 0, 'Trackback Wyczony' => -1),
    4 => array('Nie sprawdzaj Niczego' => 0, 'Sprawd wedle adresu strony' => 1, 'Sprawd cay URL' => 2, 'Sprawd wedle adresu strony i kompletnego URL' => 3, 'Check IP against Site IP' => 4, 'Sprawd IP i URL strony' => 5, 'Sprawd IP i peny URL' => 6, 'Sprawd IP, peny URL, i URL strony' => 7),
    5 => array('Tekst' => 'plaintext', 'HTML' => 'html'),
    6 => array('12' => 12, '24' => 24),
    7 => array('Ostatnia Strona' => 'last', 'Pierwsza Strona' => 'first', 'Wszystkie Strony' => 'all'),
    8 => array('Prawa' => 'right', 'Lewa' => 'left'),
    9 => array('Id do strony' => 'item', 'Poka list' => 'list', 'Poka stron gwn' => 'home', 'Poka panel sterowania' => 'admin'),
    10 => array('Brak' => '', 'Netpbm' => 'netpbm', 'ImageMagick' => 'imagemagick', 'gdLib' => 'gdlib'),
    11 => array('Lista' => 'flat', 'Chronologicznie' => 'nested', 'Wg wtku' => 'threaded', 'Bez komentarzy' => 'nocomment'),
    12 => array('Brak dostpu' => 0, 'Tylko do Odczytu' => 2, 'Odczyt-Zapis' => 3),
    13 => array('Pomi' => 0, 'Allow, with speedlimit' => 1, 'Allow, no speedlimit' => 2),
    14 => array('Niedziela' => 'Sun', 'Poniedziaek' => 'Mon'),
    15 => array('Liczbowo' => 'sortnum', 'Alfabetycznie' => 'alpha'),
    16 => array('Login nie wymagany' => 0, 'Tylko wyszukiwanie zaawansowane' => 1, 'Wyszukiwanie proste + zaawansowane' => 2),
    17 => array('Komentarze wczone' => 0, 'Komentarze wyczone' => -1),
    18 => array('Wyczone' => 0, 'Wczone (Dokadne trafienie)' => 1, 'Wczone (Pocztek sowa)' => 2, 'Wczone (Fragment sowa)' => 3),
    19 => array('Google' => 'google', 'Table' => 'table'),
    20 => array('Exact Phrase' => 'phrase', 'All of The Words' => 'all', 'Any of The Words' => 'any'),
    21 => array('HTML 4.01 Transitional' => 'html401transitional', 'HTML 4.01 Strict' => 'html401strict', 'XHTML 1.0 Transitional' => 'xhtml10transitional', 'XHTML 1.0 Strict' => 'xhtml10strict'),
    22 => array('Strict' => 'DENY', 'Same Origin' => 'SAMEORIGIN', '(disabled)' => ''),
    23 => array('Disabled' => 0, 'Enabled' => 1, 'Enabled (Default for Homepage only)' => 2),
    24 => array('Contribute' => 'contribute', 'Home' => 'home', 'Advanced Search' => 'search', 'Directory' => 'directory', 'My Account' => 'prefs', 'Plugin Entries' => 'plugins', 'Custom Entries' => 'custom', 'Site Statistics' => 'stats'),
    25 => array('New Stories' => 'story', 'New Comments' => 'comment', 'New Trackbacks' => 'trackback', 'New Pingbacks' => 'pingback', 'New Users' => 'user'),
    26 => array('G (General Audiences)' => 'G', 'PG (Parental Guidance)' => 'PG', 'R (Restricted)' => 'R', 'X (Explicit)' => 'X'),
    27 => array('Hits (asc)' => 'hits|asc', 'Hits (desc)' => 'hits|desc', 'Date (asc)' => 'date|asc', 'Date (desc)' => 'date|desc', 'Title (asc)' => 'title|asc', 'Title (desc)' => 'title|desc', 'Author (asc)' => 'uid|asc', 'Author (desc)' => 'uid|desc')
);

?>
